# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class SuperFund(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "super_fund_id": "str",
        "type": "SuperFundType",
        "name": "str",
        "abn": "str",
        "bsb": "str",
        "account_number": "str",
        "account_name": "str",
        "electronic_service_address": "str",
        "employer_number": "str",
        "spin": "str",
        "usi": "str",
        "updated_date_utc": "datetime[ms-format]",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "super_fund_id": "SuperFundID",
        "type": "Type",
        "name": "Name",
        "abn": "ABN",
        "bsb": "BSB",
        "account_number": "AccountNumber",
        "account_name": "AccountName",
        "electronic_service_address": "ElectronicServiceAddress",
        "employer_number": "EmployerNumber",
        "spin": "SPIN",
        "usi": "USI",
        "updated_date_utc": "UpdatedDateUTC",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        super_fund_id=None,
        type=None,
        name=None,
        abn=None,
        bsb=None,
        account_number=None,
        account_name=None,
        electronic_service_address=None,
        employer_number=None,
        spin=None,
        usi=None,
        updated_date_utc=None,
        validation_errors=None,
    ):  # noqa: E501
        """SuperFund - a model defined in OpenAPI"""  # noqa: E501

        self._super_fund_id = None
        self._type = None
        self._name = None
        self._abn = None
        self._bsb = None
        self._account_number = None
        self._account_name = None
        self._electronic_service_address = None
        self._employer_number = None
        self._spin = None
        self._usi = None
        self._updated_date_utc = None
        self._validation_errors = None
        self.discriminator = None

        if super_fund_id is not None:
            self.super_fund_id = super_fund_id
        self.type = type
        if name is not None:
            self.name = name
        if abn is not None:
            self.abn = abn
        if bsb is not None:
            self.bsb = bsb
        if account_number is not None:
            self.account_number = account_number
        if account_name is not None:
            self.account_name = account_name
        if electronic_service_address is not None:
            self.electronic_service_address = electronic_service_address
        if employer_number is not None:
            self.employer_number = employer_number
        if spin is not None:
            self.spin = spin
        if usi is not None:
            self.usi = usi
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def super_fund_id(self):
        """Gets the super_fund_id of this SuperFund.  # noqa: E501

        Xero identifier for a super fund  # noqa: E501

        :return: The super_fund_id of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._super_fund_id

    @super_fund_id.setter
    def super_fund_id(self, super_fund_id):
        """Sets the super_fund_id of this SuperFund.

        Xero identifier for a super fund  # noqa: E501

        :param super_fund_id: The super_fund_id of this SuperFund.  # noqa: E501
        :type: str
        """

        self._super_fund_id = super_fund_id

    @property
    def type(self):
        """Gets the type of this SuperFund.  # noqa: E501


        :return: The type of this SuperFund.  # noqa: E501
        :rtype: SuperFundType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SuperFund.


        :param type: The type of this SuperFund.  # noqa: E501
        :type: SuperFundType
        """
        if type is None:
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501

        self._type = type

    @property
    def name(self):
        """Gets the name of this SuperFund.  # noqa: E501

        Name of the super fund  # noqa: E501

        :return: The name of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SuperFund.

        Name of the super fund  # noqa: E501

        :param name: The name of this SuperFund.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def abn(self):
        """Gets the abn of this SuperFund.  # noqa: E501

        ABN of the self managed super fund  # noqa: E501

        :return: The abn of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._abn

    @abn.setter
    def abn(self, abn):
        """Sets the abn of this SuperFund.

        ABN of the self managed super fund  # noqa: E501

        :param abn: The abn of this SuperFund.  # noqa: E501
        :type: str
        """

        self._abn = abn

    @property
    def bsb(self):
        """Gets the bsb of this SuperFund.  # noqa: E501

        BSB of the self managed super fund  # noqa: E501

        :return: The bsb of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._bsb

    @bsb.setter
    def bsb(self, bsb):
        """Sets the bsb of this SuperFund.

        BSB of the self managed super fund  # noqa: E501

        :param bsb: The bsb of this SuperFund.  # noqa: E501
        :type: str
        """

        self._bsb = bsb

    @property
    def account_number(self):
        """Gets the account_number of this SuperFund.  # noqa: E501

        The account number for the self managed super fund.  # noqa: E501

        :return: The account_number of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this SuperFund.

        The account number for the self managed super fund.  # noqa: E501

        :param account_number: The account_number of this SuperFund.  # noqa: E501
        :type: str
        """

        self._account_number = account_number

    @property
    def account_name(self):
        """Gets the account_name of this SuperFund.  # noqa: E501

        The account name for the self managed super fund.  # noqa: E501

        :return: The account_name of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this SuperFund.

        The account name for the self managed super fund.  # noqa: E501

        :param account_name: The account_name of this SuperFund.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def electronic_service_address(self):
        """Gets the electronic_service_address of this SuperFund.  # noqa: E501

        The electronic service address for the self managed super fund.  # noqa: E501

        :return: The electronic_service_address of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._electronic_service_address

    @electronic_service_address.setter
    def electronic_service_address(self, electronic_service_address):
        """Sets the electronic_service_address of this SuperFund.

        The electronic service address for the self managed super fund.  # noqa: E501

        :param electronic_service_address: The electronic_service_address of this SuperFund.  # noqa: E501
        :type: str
        """

        self._electronic_service_address = electronic_service_address

    @property
    def employer_number(self):
        """Gets the employer_number of this SuperFund.  # noqa: E501

        Some funds assign a unique number to each employer  # noqa: E501

        :return: The employer_number of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._employer_number

    @employer_number.setter
    def employer_number(self, employer_number):
        """Sets the employer_number of this SuperFund.

        Some funds assign a unique number to each employer  # noqa: E501

        :param employer_number: The employer_number of this SuperFund.  # noqa: E501
        :type: str
        """

        self._employer_number = employer_number

    @property
    def spin(self):
        """Gets the spin of this SuperFund.  # noqa: E501

        The SPIN of the Regulated SuperFund. This field has been deprecated. It will only be present for legacy superfunds. New superfunds will not have a SPIN value. The USI field should be used instead of SPIN.  # noqa: E501

        :return: The spin of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._spin

    @spin.setter
    def spin(self, spin):
        """Sets the spin of this SuperFund.

        The SPIN of the Regulated SuperFund. This field has been deprecated. It will only be present for legacy superfunds. New superfunds will not have a SPIN value. The USI field should be used instead of SPIN.  # noqa: E501

        :param spin: The spin of this SuperFund.  # noqa: E501
        :type: str
        """

        self._spin = spin

    @property
    def usi(self):
        """Gets the usi of this SuperFund.  # noqa: E501

        The USI of the Regulated SuperFund  # noqa: E501

        :return: The usi of this SuperFund.  # noqa: E501
        :rtype: str
        """
        return self._usi

    @usi.setter
    def usi(self, usi):
        """Sets the usi of this SuperFund.

        The USI of the Regulated SuperFund  # noqa: E501

        :param usi: The usi of this SuperFund.  # noqa: E501
        :type: str
        """

        self._usi = usi

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this SuperFund.  # noqa: E501

        Last modified timestamp  # noqa: E501

        :return: The updated_date_utc of this SuperFund.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this SuperFund.

        Last modified timestamp  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this SuperFund.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def validation_errors(self):
        """Gets the validation_errors of this SuperFund.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this SuperFund.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this SuperFund.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this SuperFund.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class BankAccount(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"account_name": "str", "account_number": "str", "sort_code": "str"}

    attribute_map = {
        "account_name": "accountName",
        "account_number": "accountNumber",
        "sort_code": "sortCode",
    }

    def __init__(
        self, account_name=None, account_number=None, sort_code=None
    ):  # noqa: E501
        """BankAccount - a model defined in OpenAPI"""  # noqa: E501

        self._account_name = None
        self._account_number = None
        self._sort_code = None
        self.discriminator = None

        self.account_name = account_name
        self.account_number = account_number
        self.sort_code = sort_code

    @property
    def account_name(self):
        """Gets the account_name of this BankAccount.  # noqa: E501

        Bank account name (max length = 32)  # noqa: E501

        :return: The account_name of this BankAccount.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this BankAccount.

        Bank account name (max length = 32)  # noqa: E501

        :param account_name: The account_name of this BankAccount.  # noqa: E501
        :type: str
        """
        if account_name is None:
            raise ValueError(
                "Invalid value for `account_name`, must not be `None`"
            )  # noqa: E501

        self._account_name = account_name

    @property
    def account_number(self):
        """Gets the account_number of this BankAccount.  # noqa: E501

        Bank account number (digits only; max length = 8)  # noqa: E501

        :return: The account_number of this BankAccount.  # noqa: E501
        :rtype: str
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this BankAccount.

        Bank account number (digits only; max length = 8)  # noqa: E501

        :param account_number: The account_number of this BankAccount.  # noqa: E501
        :type: str
        """
        if account_number is None:
            raise ValueError(
                "Invalid value for `account_number`, must not be `None`"
            )  # noqa: E501

        self._account_number = account_number

    @property
    def sort_code(self):
        """Gets the sort_code of this BankAccount.  # noqa: E501

        Bank account sort code (6 digits)  # noqa: E501

        :return: The sort_code of this BankAccount.  # noqa: E501
        :rtype: str
        """
        return self._sort_code

    @sort_code.setter
    def sort_code(self, sort_code):
        """Sets the sort_code of this BankAccount.

        Bank account sort code (6 digits)  # noqa: E501

        :param sort_code: The sort_code of this BankAccount.  # noqa: E501
        :type: str
        """
        if sort_code is None:
            raise ValueError(
                "Invalid value for `sort_code`, must not be `None`"
            )  # noqa: E501

        self._sort_code = sort_code



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ProjectCreateOrUpdate(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "contact_id": "str",
        "name": "str",
        "estimate_amount": "float",
        "deadline_utc": "datetime",
    }

    attribute_map = {
        "contact_id": "contactId",
        "name": "name",
        "estimate_amount": "estimateAmount",
        "deadline_utc": "deadlineUtc",
    }

    def __init__(
        self, contact_id=None, name=None, estimate_amount=None, deadline_utc=None
    ):  # noqa: E501
        """ProjectCreateOrUpdate - a model defined in OpenAPI"""  # noqa: E501

        self._contact_id = None
        self._name = None
        self._estimate_amount = None
        self._deadline_utc = None
        self.discriminator = None

        if contact_id is not None:
            self.contact_id = contact_id
        self.name = name
        if estimate_amount is not None:
            self.estimate_amount = estimate_amount
        if deadline_utc is not None:
            self.deadline_utc = deadline_utc

    @property
    def contact_id(self):
        """Gets the contact_id of this ProjectCreateOrUpdate.  # noqa: E501

        Identifier of the contact this project was created for.  # noqa: E501

        :return: The contact_id of this ProjectCreateOrUpdate.  # noqa: E501
        :rtype: str
        """
        return self._contact_id

    @contact_id.setter
    def contact_id(self, contact_id):
        """Sets the contact_id of this ProjectCreateOrUpdate.

        Identifier of the contact this project was created for.  # noqa: E501

        :param contact_id: The contact_id of this ProjectCreateOrUpdate.  # noqa: E501
        :type: str
        """

        self._contact_id = contact_id

    @property
    def name(self):
        """Gets the name of this ProjectCreateOrUpdate.  # noqa: E501

        Name of the project.  # noqa: E501

        :return: The name of this ProjectCreateOrUpdate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectCreateOrUpdate.

        Name of the project.  # noqa: E501

        :param name: The name of this ProjectCreateOrUpdate.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def estimate_amount(self):
        """Gets the estimate_amount of this ProjectCreateOrUpdate.  # noqa: E501


        :return: The estimate_amount of this ProjectCreateOrUpdate.  # noqa: E501
        :rtype: float
        """
        return self._estimate_amount

    @estimate_amount.setter
    def estimate_amount(self, estimate_amount):
        """Sets the estimate_amount of this ProjectCreateOrUpdate.


        :param estimate_amount: The estimate_amount of this ProjectCreateOrUpdate.  # noqa: E501
        :type: float
        """

        self._estimate_amount = estimate_amount

    @property
    def deadline_utc(self):
        """Gets the deadline_utc of this ProjectCreateOrUpdate.  # noqa: E501

        Deadline for the project. UTC Date Time in ISO-8601 format.  # noqa: E501

        :return: The deadline_utc of this ProjectCreateOrUpdate.  # noqa: E501
        :rtype: datetime
        """
        return self._deadline_utc

    @deadline_utc.setter
    def deadline_utc(self, deadline_utc):
        """Sets the deadline_utc of this ProjectCreateOrUpdate.

        Deadline for the project. UTC Date Time in ISO-8601 format.  # noqa: E501

        :param deadline_utc: The deadline_utc of this ProjectCreateOrUpdate.  # noqa: E501
        :type: datetime
        """

        self._deadline_utc = deadline_utc



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from enum import Enum


class CalendarType(Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    allowed enum values
    """

    WEEKLY = "WEEKLY"
    FORTNIGHTLY = "FORTNIGHTLY"
    FOURWEEKLY = "FOURWEEKLY"
    MONTHLY = "MONTHLY"
    TWICEMONTHLY = "TWICEMONTHLY"
    QUARTERLY = "QUARTERLY"



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PayslipObject(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"payslip": "Payslip"}

    attribute_map = {"payslip": "Payslip"}

    def __init__(self, payslip=None):  # noqa: E501
        """PayslipObject - a model defined in OpenAPI"""  # noqa: E501

        self._payslip = None
        self.discriminator = None

        if payslip is not None:
            self.payslip = payslip

    @property
    def payslip(self):
        """Gets the payslip of this PayslipObject.  # noqa: E501


        :return: The payslip of this PayslipObject.  # noqa: E501
        :rtype: Payslip
        """
        return self._payslip

    @payslip.setter
    def payslip(self, payslip):
        """Sets the payslip of this PayslipObject.


        :param payslip: The payslip of this PayslipObject.  # noqa: E501
        :type: Payslip
        """

        self._payslip = payslip



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EmployeeTax(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "ird_number": "str",
        "tax_code": "TaxCode",
        "special_tax_rate_percentage": "float",
        "has_special_student_loan_rate": "bool",
        "special_student_loan_rate_percentage": "float",
        "is_eligible_for_kiwi_saver": "bool",
        "esct_rate_percentage": "float",
        "kiwi_saver_contributions": "str",
        "kiwi_saver_employee_contribution_rate_percentage": "float",
        "kiwi_saver_employer_contribution_rate_percentage": "float",
        "kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage": "float",
        "kiwi_saver_opt_out_date": "date",
        "kiwi_saver_contribution_holiday_end_date": "date",
        "has_student_loan_balance": "bool",
        "student_loan_balance": "float",
        "student_loan_as_at": "date",
    }

    attribute_map = {
        "ird_number": "irdNumber",
        "tax_code": "taxCode",
        "special_tax_rate_percentage": "specialTaxRatePercentage",
        "has_special_student_loan_rate": "hasSpecialStudentLoanRate",
        "special_student_loan_rate_percentage": "specialStudentLoanRatePercentage",
        "is_eligible_for_kiwi_saver": "isEligibleForKiwiSaver",
        "esct_rate_percentage": "esctRatePercentage",
        "kiwi_saver_contributions": "kiwiSaverContributions",
        "kiwi_saver_employee_contribution_rate_percentage": "kiwiSaverEmployeeContributionRatePercentage",
        "kiwi_saver_employer_contribution_rate_percentage": "kiwiSaverEmployerContributionRatePercentage",
        "kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage": "kiwiSaverEmployerSalarySacrificeContributionRatePercentage",
        "kiwi_saver_opt_out_date": "kiwiSaverOptOutDate",
        "kiwi_saver_contribution_holiday_end_date": "kiwiSaverContributionHolidayEndDate",
        "has_student_loan_balance": "hasStudentLoanBalance",
        "student_loan_balance": "studentLoanBalance",
        "student_loan_as_at": "studentLoanAsAt",
    }

    def __init__(
        self,
        ird_number=None,
        tax_code=None,
        special_tax_rate_percentage=None,
        has_special_student_loan_rate=None,
        special_student_loan_rate_percentage=None,
        is_eligible_for_kiwi_saver=None,
        esct_rate_percentage=None,
        kiwi_saver_contributions=None,
        kiwi_saver_employee_contribution_rate_percentage=None,
        kiwi_saver_employer_contribution_rate_percentage=None,
        kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage=None,
        kiwi_saver_opt_out_date=None,
        kiwi_saver_contribution_holiday_end_date=None,
        has_student_loan_balance=None,
        student_loan_balance=None,
        student_loan_as_at=None,
    ):  # noqa: E501
        """EmployeeTax - a model defined in OpenAPI"""  # noqa: E501

        self._ird_number = None
        self._tax_code = None
        self._special_tax_rate_percentage = None
        self._has_special_student_loan_rate = None
        self._special_student_loan_rate_percentage = None
        self._is_eligible_for_kiwi_saver = None
        self._esct_rate_percentage = None
        self._kiwi_saver_contributions = None
        self._kiwi_saver_employee_contribution_rate_percentage = None
        self._kiwi_saver_employer_contribution_rate_percentage = None
        self._kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage = None
        self._kiwi_saver_opt_out_date = None
        self._kiwi_saver_contribution_holiday_end_date = None
        self._has_student_loan_balance = None
        self._student_loan_balance = None
        self._student_loan_as_at = None
        self.discriminator = None

        if ird_number is not None:
            self.ird_number = ird_number
        if tax_code is not None:
            self.tax_code = tax_code
        if special_tax_rate_percentage is not None:
            self.special_tax_rate_percentage = special_tax_rate_percentage
        if has_special_student_loan_rate is not None:
            self.has_special_student_loan_rate = has_special_student_loan_rate
        if special_student_loan_rate_percentage is not None:
            self.special_student_loan_rate_percentage = (
                special_student_loan_rate_percentage
            )
        if is_eligible_for_kiwi_saver is not None:
            self.is_eligible_for_kiwi_saver = is_eligible_for_kiwi_saver
        if esct_rate_percentage is not None:
            self.esct_rate_percentage = esct_rate_percentage
        if kiwi_saver_contributions is not None:
            self.kiwi_saver_contributions = kiwi_saver_contributions
        if kiwi_saver_employee_contribution_rate_percentage is not None:
            self.kiwi_saver_employee_contribution_rate_percentage = (
                kiwi_saver_employee_contribution_rate_percentage
            )
        if kiwi_saver_employer_contribution_rate_percentage is not None:
            self.kiwi_saver_employer_contribution_rate_percentage = (
                kiwi_saver_employer_contribution_rate_percentage
            )
        if (
            kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage
            is not None
        ):
            self.kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage = (
                kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage
            )
        if kiwi_saver_opt_out_date is not None:
            self.kiwi_saver_opt_out_date = kiwi_saver_opt_out_date
        if kiwi_saver_contribution_holiday_end_date is not None:
            self.kiwi_saver_contribution_holiday_end_date = (
                kiwi_saver_contribution_holiday_end_date
            )
        if has_student_loan_balance is not None:
            self.has_student_loan_balance = has_student_loan_balance
        if student_loan_balance is not None:
            self.student_loan_balance = student_loan_balance
        if student_loan_as_at is not None:
            self.student_loan_as_at = student_loan_as_at

    @property
    def ird_number(self):
        """Gets the ird_number of this EmployeeTax.  # noqa: E501

        The IRD Number.  # noqa: E501

        :return: The ird_number of this EmployeeTax.  # noqa: E501
        :rtype: str
        """
        return self._ird_number

    @ird_number.setter
    def ird_number(self, ird_number):
        """Sets the ird_number of this EmployeeTax.

        The IRD Number.  # noqa: E501

        :param ird_number: The ird_number of this EmployeeTax.  # noqa: E501
        :type: str
        """

        self._ird_number = ird_number

    @property
    def tax_code(self):
        """Gets the tax_code of this EmployeeTax.  # noqa: E501


        :return: The tax_code of this EmployeeTax.  # noqa: E501
        :rtype: TaxCode
        """
        return self._tax_code

    @tax_code.setter
    def tax_code(self, tax_code):
        """Sets the tax_code of this EmployeeTax.


        :param tax_code: The tax_code of this EmployeeTax.  # noqa: E501
        :type: TaxCode
        """

        self._tax_code = tax_code

    @property
    def special_tax_rate_percentage(self):
        """Gets the special_tax_rate_percentage of this EmployeeTax.  # noqa: E501

        Special tax rate percentage.  # noqa: E501

        :return: The special_tax_rate_percentage of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._special_tax_rate_percentage

    @special_tax_rate_percentage.setter
    def special_tax_rate_percentage(self, special_tax_rate_percentage):
        """Sets the special_tax_rate_percentage of this EmployeeTax.

        Special tax rate percentage.  # noqa: E501

        :param special_tax_rate_percentage: The special_tax_rate_percentage of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._special_tax_rate_percentage = special_tax_rate_percentage

    @property
    def has_special_student_loan_rate(self):
        """Gets the has_special_student_loan_rate of this EmployeeTax.  # noqa: E501

        Does the employee has a special student loan rate?  # noqa: E501

        :return: The has_special_student_loan_rate of this EmployeeTax.  # noqa: E501
        :rtype: bool
        """
        return self._has_special_student_loan_rate

    @has_special_student_loan_rate.setter
    def has_special_student_loan_rate(self, has_special_student_loan_rate):
        """Sets the has_special_student_loan_rate of this EmployeeTax.

        Does the employee has a special student loan rate?  # noqa: E501

        :param has_special_student_loan_rate: The has_special_student_loan_rate of this EmployeeTax.  # noqa: E501
        :type: bool
        """

        self._has_special_student_loan_rate = has_special_student_loan_rate

    @property
    def special_student_loan_rate_percentage(self):
        """Gets the special_student_loan_rate_percentage of this EmployeeTax.  # noqa: E501

        The employee student loan rate percentage.  # noqa: E501

        :return: The special_student_loan_rate_percentage of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._special_student_loan_rate_percentage

    @special_student_loan_rate_percentage.setter
    def special_student_loan_rate_percentage(
        self, special_student_loan_rate_percentage
    ):
        """Sets the special_student_loan_rate_percentage of this EmployeeTax.

        The employee student loan rate percentage.  # noqa: E501

        :param special_student_loan_rate_percentage: The special_student_loan_rate_percentage of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._special_student_loan_rate_percentage = (
            special_student_loan_rate_percentage
        )

    @property
    def is_eligible_for_kiwi_saver(self):
        """Gets the is_eligible_for_kiwi_saver of this EmployeeTax.  # noqa: E501

        The employee eligibility for KiwiSaver.  # noqa: E501

        :return: The is_eligible_for_kiwi_saver of this EmployeeTax.  # noqa: E501
        :rtype: bool
        """
        return self._is_eligible_for_kiwi_saver

    @is_eligible_for_kiwi_saver.setter
    def is_eligible_for_kiwi_saver(self, is_eligible_for_kiwi_saver):
        """Sets the is_eligible_for_kiwi_saver of this EmployeeTax.

        The employee eligibility for KiwiSaver.  # noqa: E501

        :param is_eligible_for_kiwi_saver: The is_eligible_for_kiwi_saver of this EmployeeTax.  # noqa: E501
        :type: bool
        """

        self._is_eligible_for_kiwi_saver = is_eligible_for_kiwi_saver

    @property
    def esct_rate_percentage(self):
        """Gets the esct_rate_percentage of this EmployeeTax.  # noqa: E501

        Employer superannuation contribution tax rate.  # noqa: E501

        :return: The esct_rate_percentage of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._esct_rate_percentage

    @esct_rate_percentage.setter
    def esct_rate_percentage(self, esct_rate_percentage):
        """Sets the esct_rate_percentage of this EmployeeTax.

        Employer superannuation contribution tax rate.  # noqa: E501

        :param esct_rate_percentage: The esct_rate_percentage of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._esct_rate_percentage = esct_rate_percentage

    @property
    def kiwi_saver_contributions(self):
        """Gets the kiwi_saver_contributions of this EmployeeTax.  # noqa: E501

        Contribution Option which can be 'MakeContributions' 'OptOut', 'OnAContributionsHoliday', 'OnASavingsSuspension', 'NotCurrentlyAKiwiSaverMember' for employees without a KiwiSaver membership  # noqa: E501

        :return: The kiwi_saver_contributions of this EmployeeTax.  # noqa: E501
        :rtype: str
        """
        return self._kiwi_saver_contributions

    @kiwi_saver_contributions.setter
    def kiwi_saver_contributions(self, kiwi_saver_contributions):
        """Sets the kiwi_saver_contributions of this EmployeeTax.

        Contribution Option which can be 'MakeContributions' 'OptOut', 'OnAContributionsHoliday', 'OnASavingsSuspension', 'NotCurrentlyAKiwiSaverMember' for employees without a KiwiSaver membership  # noqa: E501

        :param kiwi_saver_contributions: The kiwi_saver_contributions of this EmployeeTax.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "MakeContributions",
            "OptOut",
            "OnAContributionsHoliday",
            "OnASavingsSuspension",
            "NotCurrentlyAKiwiSaverMember",
            "None",
        ]  # noqa: E501

        if kiwi_saver_contributions:
            if kiwi_saver_contributions not in allowed_values:
                raise ValueError(
                    "Invalid value for `kiwi_saver_contributions` ({0}), must be one of {1}".format(  # noqa: E501
                        kiwi_saver_contributions, allowed_values
                    )
                )

        self._kiwi_saver_contributions = kiwi_saver_contributions

    @property
    def kiwi_saver_employee_contribution_rate_percentage(self):
        """Gets the kiwi_saver_employee_contribution_rate_percentage of this EmployeeTax.  # noqa: E501

        Employee Contribution percentage.  # noqa: E501

        :return: The kiwi_saver_employee_contribution_rate_percentage of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._kiwi_saver_employee_contribution_rate_percentage

    @kiwi_saver_employee_contribution_rate_percentage.setter
    def kiwi_saver_employee_contribution_rate_percentage(
        self, kiwi_saver_employee_contribution_rate_percentage
    ):
        """Sets the kiwi_saver_employee_contribution_rate_percentage of this EmployeeTax.

        Employee Contribution percentage.  # noqa: E501

        :param kiwi_saver_employee_contribution_rate_percentage: The kiwi_saver_employee_contribution_rate_percentage of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._kiwi_saver_employee_contribution_rate_percentage = (
            kiwi_saver_employee_contribution_rate_percentage
        )

    @property
    def kiwi_saver_employer_contribution_rate_percentage(self):
        """Gets the kiwi_saver_employer_contribution_rate_percentage of this EmployeeTax.  # noqa: E501

        Employer Contribution percentage.  # noqa: E501

        :return: The kiwi_saver_employer_contribution_rate_percentage of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._kiwi_saver_employer_contribution_rate_percentage

    @kiwi_saver_employer_contribution_rate_percentage.setter
    def kiwi_saver_employer_contribution_rate_percentage(
        self, kiwi_saver_employer_contribution_rate_percentage
    ):
        """Sets the kiwi_saver_employer_contribution_rate_percentage of this EmployeeTax.

        Employer Contribution percentage.  # noqa: E501

        :param kiwi_saver_employer_contribution_rate_percentage: The kiwi_saver_employer_contribution_rate_percentage of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._kiwi_saver_employer_contribution_rate_percentage = (
            kiwi_saver_employer_contribution_rate_percentage
        )

    @property
    def kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage(self):
        """Gets the kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage of this EmployeeTax.  # noqa: E501

        Employer Contribution through Salary Sacrifice percentage.  # noqa: E501

        :return: The kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage

    @kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage.setter
    def kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage(
        self, kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage
    ):
        """Sets the kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage of this EmployeeTax.

        Employer Contribution through Salary Sacrifice percentage.  # noqa: E501

        :param kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage: The kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage = (
            kiwi_saver_employer_salary_sacrifice_contribution_rate_percentage
        )

    @property
    def kiwi_saver_opt_out_date(self):
        """Gets the kiwi_saver_opt_out_date of this EmployeeTax.  # noqa: E501

        Opt Out Date.  # noqa: E501

        :return: The kiwi_saver_opt_out_date of this EmployeeTax.  # noqa: E501
        :rtype: date
        """
        return self._kiwi_saver_opt_out_date

    @kiwi_saver_opt_out_date.setter
    def kiwi_saver_opt_out_date(self, kiwi_saver_opt_out_date):
        """Sets the kiwi_saver_opt_out_date of this EmployeeTax.

        Opt Out Date.  # noqa: E501

        :param kiwi_saver_opt_out_date: The kiwi_saver_opt_out_date of this EmployeeTax.  # noqa: E501
        :type: date
        """

        self._kiwi_saver_opt_out_date = kiwi_saver_opt_out_date

    @property
    def kiwi_saver_contribution_holiday_end_date(self):
        """Gets the kiwi_saver_contribution_holiday_end_date of this EmployeeTax.  # noqa: E501

        Contribution holiday expiry date or end date.  # noqa: E501

        :return: The kiwi_saver_contribution_holiday_end_date of this EmployeeTax.  # noqa: E501
        :rtype: date
        """
        return self._kiwi_saver_contribution_holiday_end_date

    @kiwi_saver_contribution_holiday_end_date.setter
    def kiwi_saver_contribution_holiday_end_date(
        self, kiwi_saver_contribution_holiday_end_date
    ):
        """Sets the kiwi_saver_contribution_holiday_end_date of this EmployeeTax.

        Contribution holiday expiry date or end date.  # noqa: E501

        :param kiwi_saver_contribution_holiday_end_date: The kiwi_saver_contribution_holiday_end_date of this EmployeeTax.  # noqa: E501
        :type: date
        """

        self._kiwi_saver_contribution_holiday_end_date = (
            kiwi_saver_contribution_holiday_end_date
        )

    @property
    def has_student_loan_balance(self):
        """Gets the has_student_loan_balance of this EmployeeTax.  # noqa: E501

        Does the employee have a remaining student loan balance? Set a remaining balance if you have received a letter from IR.  # noqa: E501

        :return: The has_student_loan_balance of this EmployeeTax.  # noqa: E501
        :rtype: bool
        """
        return self._has_student_loan_balance

    @has_student_loan_balance.setter
    def has_student_loan_balance(self, has_student_loan_balance):
        """Sets the has_student_loan_balance of this EmployeeTax.

        Does the employee have a remaining student loan balance? Set a remaining balance if you have received a letter from IR.  # noqa: E501

        :param has_student_loan_balance: The has_student_loan_balance of this EmployeeTax.  # noqa: E501
        :type: bool
        """

        self._has_student_loan_balance = has_student_loan_balance

    @property
    def student_loan_balance(self):
        """Gets the student_loan_balance of this EmployeeTax.  # noqa: E501

        The employee's student loan balance shown on the letter from IR.  # noqa: E501

        :return: The student_loan_balance of this EmployeeTax.  # noqa: E501
        :rtype: float
        """
        return self._student_loan_balance

    @student_loan_balance.setter
    def student_loan_balance(self, student_loan_balance):
        """Sets the student_loan_balance of this EmployeeTax.

        The employee's student loan balance shown on the letter from IR.  # noqa: E501

        :param student_loan_balance: The student_loan_balance of this EmployeeTax.  # noqa: E501
        :type: float
        """

        self._student_loan_balance = student_loan_balance

    @property
    def student_loan_as_at(self):
        """Gets the student_loan_as_at of this EmployeeTax.  # noqa: E501

        The date of the letter from IR.  # noqa: E501

        :return: The student_loan_as_at of this EmployeeTax.  # noqa: E501
        :rtype: date
        """
        return self._student_loan_as_at

    @student_loan_as_at.setter
    def student_loan_as_at(self, student_loan_as_at):
        """Sets the student_loan_as_at of this EmployeeTax.

        The date of the letter from IR.  # noqa: E501

        :param student_loan_as_at: The student_loan_as_at of this EmployeeTax.  # noqa: E501
        :type: date
        """

        self._student_loan_as_at = student_loan_as_at



# coding: utf-8

"""
    Xero OAuth 2 Identity Service API

    These endpoints are related to managing authentication tokens and identity for Xero API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class AccessToken(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "id_token": "str",
        "access_token": "str",
        "expires_in": "int",
        "token_type": "str",
        "refresh_token": "str",
    }

    attribute_map = {
        "id_token": "id_token",
        "access_token": "access_token",
        "expires_in": "expires_in",
        "token_type": "token_type",
        "refresh_token": "refresh_token",
    }

    def __init__(
        self,
        id_token=None,
        access_token=None,
        expires_in=None,
        token_type=None,
        refresh_token=None,
    ):  # noqa: E501
        """AccessToken - a model defined in OpenAPI"""  # noqa: E501

        self._id_token = None
        self._access_token = None
        self._expires_in = None
        self._token_type = None
        self._refresh_token = None
        self.discriminator = None

        if id_token is not None:
            self.id_token = id_token
        if access_token is not None:
            self.access_token = access_token
        if expires_in is not None:
            self.expires_in = expires_in
        if token_type is not None:
            self.token_type = token_type
        if refresh_token is not None:
            self.refresh_token = refresh_token

    @property
    def id_token(self):
        """Gets the id_token of this AccessToken.  # noqa: E501

        Xero unique identifier  # noqa: E501

        :return: The id_token of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._id_token

    @id_token.setter
    def id_token(self, id_token):
        """Sets the id_token of this AccessToken.

        Xero unique identifier  # noqa: E501

        :param id_token: The id_token of this AccessToken.  # noqa: E501
        :type: str
        """

        self._id_token = id_token

    @property
    def access_token(self):
        """Gets the access_token of this AccessToken.  # noqa: E501

        access token provided during authentication flow  # noqa: E501

        :return: The access_token of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this AccessToken.

        access token provided during authentication flow  # noqa: E501

        :param access_token: The access_token of this AccessToken.  # noqa: E501
        :type: str
        """

        self._access_token = access_token

    @property
    def expires_in(self):
        """Gets the expires_in of this AccessToken.  # noqa: E501

        time in seconds until access token expires.  # noqa: E501

        :return: The expires_in of this AccessToken.  # noqa: E501
        :rtype: int
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this AccessToken.

        time in seconds until access token expires.  # noqa: E501

        :param expires_in: The expires_in of this AccessToken.  # noqa: E501
        :type: int
        """

        self._expires_in = expires_in

    @property
    def token_type(self):
        """Gets the token_type of this AccessToken.  # noqa: E501

        type of token i.e. Bearer  # noqa: E501

        :return: The token_type of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this AccessToken.

        type of token i.e. Bearer  # noqa: E501

        :param token_type: The token_type of this AccessToken.  # noqa: E501
        :type: str
        """

        self._token_type = token_type

    @property
    def refresh_token(self):
        """Gets the refresh_token of this AccessToken.  # noqa: E501

        token used to refresh an expired access token  # noqa: E501

        :return: The refresh_token of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this AccessToken.

        token used to refresh an expired access token  # noqa: E501

        :param refresh_token: The refresh_token of this AccessToken.  # noqa: E501
        :type: str
        """

        self._refresh_token = refresh_token



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class LeaveType(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "leave_type_id": "str",
        "name": "str",
        "is_paid_leave": "bool",
        "show_on_payslip": "bool",
        "updated_date_utc": "datetime",
        "is_active": "bool",
    }

    attribute_map = {
        "leave_type_id": "leaveTypeID",
        "name": "name",
        "is_paid_leave": "isPaidLeave",
        "show_on_payslip": "showOnPayslip",
        "updated_date_utc": "updatedDateUTC",
        "is_active": "isActive",
    }

    def __init__(
        self,
        leave_type_id=None,
        name=None,
        is_paid_leave=None,
        show_on_payslip=None,
        updated_date_utc=None,
        is_active=None,
    ):  # noqa: E501
        """LeaveType - a model defined in OpenAPI"""  # noqa: E501

        self._leave_type_id = None
        self._name = None
        self._is_paid_leave = None
        self._show_on_payslip = None
        self._updated_date_utc = None
        self._is_active = None
        self.discriminator = None

        if leave_type_id is not None:
            self.leave_type_id = leave_type_id
        self.name = name
        self.is_paid_leave = is_paid_leave
        self.show_on_payslip = show_on_payslip
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if is_active is not None:
            self.is_active = is_active

    @property
    def leave_type_id(self):
        """Gets the leave_type_id of this LeaveType.  # noqa: E501

        Xero unique identifier for the leave type  # noqa: E501

        :return: The leave_type_id of this LeaveType.  # noqa: E501
        :rtype: str
        """
        return self._leave_type_id

    @leave_type_id.setter
    def leave_type_id(self, leave_type_id):
        """Sets the leave_type_id of this LeaveType.

        Xero unique identifier for the leave type  # noqa: E501

        :param leave_type_id: The leave_type_id of this LeaveType.  # noqa: E501
        :type: str
        """

        self._leave_type_id = leave_type_id

    @property
    def name(self):
        """Gets the name of this LeaveType.  # noqa: E501

        Name of the leave type  # noqa: E501

        :return: The name of this LeaveType.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LeaveType.

        Name of the leave type  # noqa: E501

        :param name: The name of this LeaveType.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def is_paid_leave(self):
        """Gets the is_paid_leave of this LeaveType.  # noqa: E501

        Indicate that an employee will be paid when taking this type of leave  # noqa: E501

        :return: The is_paid_leave of this LeaveType.  # noqa: E501
        :rtype: bool
        """
        return self._is_paid_leave

    @is_paid_leave.setter
    def is_paid_leave(self, is_paid_leave):
        """Sets the is_paid_leave of this LeaveType.

        Indicate that an employee will be paid when taking this type of leave  # noqa: E501

        :param is_paid_leave: The is_paid_leave of this LeaveType.  # noqa: E501
        :type: bool
        """
        if is_paid_leave is None:
            raise ValueError(
                "Invalid value for `is_paid_leave`, must not be `None`"
            )  # noqa: E501

        self._is_paid_leave = is_paid_leave

    @property
    def show_on_payslip(self):
        """Gets the show_on_payslip of this LeaveType.  # noqa: E501

        Indicate that a balance for this leave type to be shown on the employee’s payslips  # noqa: E501

        :return: The show_on_payslip of this LeaveType.  # noqa: E501
        :rtype: bool
        """
        return self._show_on_payslip

    @show_on_payslip.setter
    def show_on_payslip(self, show_on_payslip):
        """Sets the show_on_payslip of this LeaveType.

        Indicate that a balance for this leave type to be shown on the employee’s payslips  # noqa: E501

        :param show_on_payslip: The show_on_payslip of this LeaveType.  # noqa: E501
        :type: bool
        """
        if show_on_payslip is None:
            raise ValueError(
                "Invalid value for `show_on_payslip`, must not be `None`"
            )  # noqa: E501

        self._show_on_payslip = show_on_payslip

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this LeaveType.  # noqa: E501

        UTC timestamp of last update to the leave type note  # noqa: E501

        :return: The updated_date_utc of this LeaveType.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this LeaveType.

        UTC timestamp of last update to the leave type note  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this LeaveType.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def is_active(self):
        """Gets the is_active of this LeaveType.  # noqa: E501

        Shows whether the leave type is active or not  # noqa: E501

        :return: The is_active of this LeaveType.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this LeaveType.

        Shows whether the leave type is active or not  # noqa: E501

        :param is_active: The is_active of this LeaveType.  # noqa: E501
        :type: bool
        """

        self._is_active = is_active



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TimeEntryCreateOrUpdate(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "user_id": "str",
        "task_id": "str",
        "date_utc": "datetime",
        "duration": "int",
        "description": "str",
    }

    attribute_map = {
        "user_id": "userId",
        "task_id": "taskId",
        "date_utc": "dateUtc",
        "duration": "duration",
        "description": "description",
    }

    def __init__(
        self, user_id=None, task_id=None, date_utc=None, duration=None, description=None
    ):  # noqa: E501
        """TimeEntryCreateOrUpdate - a model defined in OpenAPI"""  # noqa: E501

        self._user_id = None
        self._task_id = None
        self._date_utc = None
        self._duration = None
        self._description = None
        self.discriminator = None

        self.user_id = user_id
        self.task_id = task_id
        self.date_utc = date_utc
        self.duration = duration
        if description is not None:
            self.description = description

    @property
    def user_id(self):
        """Gets the user_id of this TimeEntryCreateOrUpdate.  # noqa: E501

        The xero user identifier of the person logging the time.  # noqa: E501

        :return: The user_id of this TimeEntryCreateOrUpdate.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this TimeEntryCreateOrUpdate.

        The xero user identifier of the person logging the time.  # noqa: E501

        :param user_id: The user_id of this TimeEntryCreateOrUpdate.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError(
                "Invalid value for `user_id`, must not be `None`"
            )  # noqa: E501

        self._user_id = user_id

    @property
    def task_id(self):
        """Gets the task_id of this TimeEntryCreateOrUpdate.  # noqa: E501

        Identifier of the task that time entry is logged against.  # noqa: E501

        :return: The task_id of this TimeEntryCreateOrUpdate.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this TimeEntryCreateOrUpdate.

        Identifier of the task that time entry is logged against.  # noqa: E501

        :param task_id: The task_id of this TimeEntryCreateOrUpdate.  # noqa: E501
        :type: str
        """
        if task_id is None:
            raise ValueError(
                "Invalid value for `task_id`, must not be `None`"
            )  # noqa: E501

        self._task_id = task_id

    @property
    def date_utc(self):
        """Gets the date_utc of this TimeEntryCreateOrUpdate.  # noqa: E501

        Date time entry is logged on. UTC Date Time in ISO-8601 format.  # noqa: E501

        :return: The date_utc of this TimeEntryCreateOrUpdate.  # noqa: E501
        :rtype: datetime
        """
        return self._date_utc

    @date_utc.setter
    def date_utc(self, date_utc):
        """Sets the date_utc of this TimeEntryCreateOrUpdate.

        Date time entry is logged on. UTC Date Time in ISO-8601 format.  # noqa: E501

        :param date_utc: The date_utc of this TimeEntryCreateOrUpdate.  # noqa: E501
        :type: datetime
        """
        if date_utc is None:
            raise ValueError(
                "Invalid value for `date_utc`, must not be `None`"
            )  # noqa: E501

        self._date_utc = date_utc

    @property
    def duration(self):
        """Gets the duration of this TimeEntryCreateOrUpdate.  # noqa: E501

        Number of minutes to be logged. Duration is between 1 and 59940 inclusively.  # noqa: E501

        :return: The duration of this TimeEntryCreateOrUpdate.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this TimeEntryCreateOrUpdate.

        Number of minutes to be logged. Duration is between 1 and 59940 inclusively.  # noqa: E501

        :param duration: The duration of this TimeEntryCreateOrUpdate.  # noqa: E501
        :type: int
        """
        if duration is None:
            raise ValueError(
                "Invalid value for `duration`, must not be `None`"
            )  # noqa: E501

        self._duration = duration

    @property
    def description(self):
        """Gets the description of this TimeEntryCreateOrUpdate.  # noqa: E501

        An optional description of the time entry, will be set to null if not provided during update.  # noqa: E501

        :return: The description of this TimeEntryCreateOrUpdate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TimeEntryCreateOrUpdate.

        An optional description of the time entry, will be set to null if not provided during update.  # noqa: E501

        :param description: The description of this TimeEntryCreateOrUpdate.  # noqa: E501
        :type: str
        """

        self._description = description



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Balances(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "accounts_receivable": "AccountsReceivable",
        "accounts_payable": "AccountsPayable",
    }

    attribute_map = {
        "accounts_receivable": "AccountsReceivable",
        "accounts_payable": "AccountsPayable",
    }

    def __init__(self, accounts_receivable=None, accounts_payable=None):  # noqa: E501
        """Balances - a model defined in OpenAPI"""  # noqa: E501

        self._accounts_receivable = None
        self._accounts_payable = None
        self.discriminator = None

        if accounts_receivable is not None:
            self.accounts_receivable = accounts_receivable
        if accounts_payable is not None:
            self.accounts_payable = accounts_payable

    @property
    def accounts_receivable(self):
        """Gets the accounts_receivable of this Balances.  # noqa: E501


        :return: The accounts_receivable of this Balances.  # noqa: E501
        :rtype: AccountsReceivable
        """
        return self._accounts_receivable

    @accounts_receivable.setter
    def accounts_receivable(self, accounts_receivable):
        """Sets the accounts_receivable of this Balances.


        :param accounts_receivable: The accounts_receivable of this Balances.  # noqa: E501
        :type: AccountsReceivable
        """

        self._accounts_receivable = accounts_receivable

    @property
    def accounts_payable(self):
        """Gets the accounts_payable of this Balances.  # noqa: E501


        :return: The accounts_payable of this Balances.  # noqa: E501
        :rtype: AccountsPayable
        """
        return self._accounts_payable

    @accounts_payable.setter
    def accounts_payable(self, accounts_payable):
        """Sets the accounts_payable of this Balances.


        :param accounts_payable: The accounts_payable of this Balances.  # noqa: E501
        :type: AccountsPayable
        """

        self._accounts_payable = accounts_payable



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class CreditNotes(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"credit_notes": "list[CreditNote]"}

    attribute_map = {"credit_notes": "CreditNotes"}

    def __init__(self, credit_notes=None):  # noqa: E501
        """CreditNotes - a model defined in OpenAPI"""  # noqa: E501

        self._credit_notes = None
        self.discriminator = None

        if credit_notes is not None:
            self.credit_notes = credit_notes

    @property
    def credit_notes(self):
        """Gets the credit_notes of this CreditNotes.  # noqa: E501


        :return: The credit_notes of this CreditNotes.  # noqa: E501
        :rtype: list[CreditNote]
        """
        return self._credit_notes

    @credit_notes.setter
    def credit_notes(self, credit_notes):
        """Sets the credit_notes of this CreditNotes.


        :param credit_notes: The credit_notes of this CreditNotes.  # noqa: E501
        :type: list[CreditNote]
        """

        self._credit_notes = credit_notes



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Attachment(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "attachment_id": "str",
        "file_name": "str",
        "url": "str",
        "mime_type": "str",
        "content_length": "int",
        "include_online": "bool",
    }

    attribute_map = {
        "attachment_id": "AttachmentID",
        "file_name": "FileName",
        "url": "Url",
        "mime_type": "MimeType",
        "content_length": "ContentLength",
        "include_online": "IncludeOnline",
    }

    def __init__(
        self,
        attachment_id=None,
        file_name=None,
        url=None,
        mime_type=None,
        content_length=None,
        include_online=None,
    ):  # noqa: E501
        """Attachment - a model defined in OpenAPI"""  # noqa: E501

        self._attachment_id = None
        self._file_name = None
        self._url = None
        self._mime_type = None
        self._content_length = None
        self._include_online = None
        self.discriminator = None

        if attachment_id is not None:
            self.attachment_id = attachment_id
        if file_name is not None:
            self.file_name = file_name
        if url is not None:
            self.url = url
        if mime_type is not None:
            self.mime_type = mime_type
        if content_length is not None:
            self.content_length = content_length
        if include_online is not None:
            self.include_online = include_online

    @property
    def attachment_id(self):
        """Gets the attachment_id of this Attachment.  # noqa: E501

        Unique ID for the file  # noqa: E501

        :return: The attachment_id of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this Attachment.

        Unique ID for the file  # noqa: E501

        :param attachment_id: The attachment_id of this Attachment.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def file_name(self):
        """Gets the file_name of this Attachment.  # noqa: E501

        Name of the file  # noqa: E501

        :return: The file_name of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this Attachment.

        Name of the file  # noqa: E501

        :param file_name: The file_name of this Attachment.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def url(self):
        """Gets the url of this Attachment.  # noqa: E501

        URL to the file on xero.com  # noqa: E501

        :return: The url of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Attachment.

        URL to the file on xero.com  # noqa: E501

        :param url: The url of this Attachment.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def mime_type(self):
        """Gets the mime_type of this Attachment.  # noqa: E501

        Type of file  # noqa: E501

        :return: The mime_type of this Attachment.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this Attachment.

        Type of file  # noqa: E501

        :param mime_type: The mime_type of this Attachment.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def content_length(self):
        """Gets the content_length of this Attachment.  # noqa: E501

        Length of the file content  # noqa: E501

        :return: The content_length of this Attachment.  # noqa: E501
        :rtype: int
        """
        return self._content_length

    @content_length.setter
    def content_length(self, content_length):
        """Sets the content_length of this Attachment.

        Length of the file content  # noqa: E501

        :param content_length: The content_length of this Attachment.  # noqa: E501
        :type: int
        """

        self._content_length = content_length

    @property
    def include_online(self):
        """Gets the include_online of this Attachment.  # noqa: E501

        Include the file with the online invoice  # noqa: E501

        :return: The include_online of this Attachment.  # noqa: E501
        :rtype: bool
        """
        return self._include_online

    @include_online.setter
    def include_online(self, include_online):
        """Sets the include_online of this Attachment.

        Include the file with the online invoice  # noqa: E501

        :param include_online: The include_online of this Attachment.  # noqa: E501
        :type: bool
        """

        self._include_online = include_online



# coding: utf-8

"""
    Xero Assets API

    The Assets API exposes fixed asset related functions of the Xero Accounting application and can be used for a variety of purposes such as creating assets, retrieving asset valuations etc.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Setting(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "asset_number_prefix": "str",
        "asset_number_sequence": "str",
        "asset_start_date": "date",
        "last_depreciation_date": "date",
        "default_gain_on_disposal_account_id": "str",
        "default_loss_on_disposal_account_id": "str",
        "default_capital_gain_on_disposal_account_id": "str",
        "opt_in_for_tax": "bool",
    }

    attribute_map = {
        "asset_number_prefix": "assetNumberPrefix",
        "asset_number_sequence": "assetNumberSequence",
        "asset_start_date": "assetStartDate",
        "last_depreciation_date": "lastDepreciationDate",
        "default_gain_on_disposal_account_id": "defaultGainOnDisposalAccountId",
        "default_loss_on_disposal_account_id": "defaultLossOnDisposalAccountId",
        "default_capital_gain_on_disposal_account_id": "defaultCapitalGainOnDisposalAccountId",
        "opt_in_for_tax": "optInForTax",
    }

    def __init__(
        self,
        asset_number_prefix=None,
        asset_number_sequence=None,
        asset_start_date=None,
        last_depreciation_date=None,
        default_gain_on_disposal_account_id=None,
        default_loss_on_disposal_account_id=None,
        default_capital_gain_on_disposal_account_id=None,
        opt_in_for_tax=None,
    ):  # noqa: E501
        """Setting - a model defined in OpenAPI"""  # noqa: E501

        self._asset_number_prefix = None
        self._asset_number_sequence = None
        self._asset_start_date = None
        self._last_depreciation_date = None
        self._default_gain_on_disposal_account_id = None
        self._default_loss_on_disposal_account_id = None
        self._default_capital_gain_on_disposal_account_id = None
        self._opt_in_for_tax = None
        self.discriminator = None

        if asset_number_prefix is not None:
            self.asset_number_prefix = asset_number_prefix
        if asset_number_sequence is not None:
            self.asset_number_sequence = asset_number_sequence
        if asset_start_date is not None:
            self.asset_start_date = asset_start_date
        if last_depreciation_date is not None:
            self.last_depreciation_date = last_depreciation_date
        if default_gain_on_disposal_account_id is not None:
            self.default_gain_on_disposal_account_id = (
                default_gain_on_disposal_account_id
            )
        if default_loss_on_disposal_account_id is not None:
            self.default_loss_on_disposal_account_id = (
                default_loss_on_disposal_account_id
            )
        if default_capital_gain_on_disposal_account_id is not None:
            self.default_capital_gain_on_disposal_account_id = (
                default_capital_gain_on_disposal_account_id
            )
        if opt_in_for_tax is not None:
            self.opt_in_for_tax = opt_in_for_tax

    @property
    def asset_number_prefix(self):
        """Gets the asset_number_prefix of this Setting.  # noqa: E501

        The prefix used for fixed asset numbers (“FA-” by default)  # noqa: E501

        :return: The asset_number_prefix of this Setting.  # noqa: E501
        :rtype: str
        """
        return self._asset_number_prefix

    @asset_number_prefix.setter
    def asset_number_prefix(self, asset_number_prefix):
        """Sets the asset_number_prefix of this Setting.

        The prefix used for fixed asset numbers (“FA-” by default)  # noqa: E501

        :param asset_number_prefix: The asset_number_prefix of this Setting.  # noqa: E501
        :type: str
        """

        self._asset_number_prefix = asset_number_prefix

    @property
    def asset_number_sequence(self):
        """Gets the asset_number_sequence of this Setting.  # noqa: E501

        The next available sequence number  # noqa: E501

        :return: The asset_number_sequence of this Setting.  # noqa: E501
        :rtype: str
        """
        return self._asset_number_sequence

    @asset_number_sequence.setter
    def asset_number_sequence(self, asset_number_sequence):
        """Sets the asset_number_sequence of this Setting.

        The next available sequence number  # noqa: E501

        :param asset_number_sequence: The asset_number_sequence of this Setting.  # noqa: E501
        :type: str
        """

        self._asset_number_sequence = asset_number_sequence

    @property
    def asset_start_date(self):
        """Gets the asset_start_date of this Setting.  # noqa: E501

        The date depreciation calculations started on registered fixed assets in Xero  # noqa: E501

        :return: The asset_start_date of this Setting.  # noqa: E501
        :rtype: date
        """
        return self._asset_start_date

    @asset_start_date.setter
    def asset_start_date(self, asset_start_date):
        """Sets the asset_start_date of this Setting.

        The date depreciation calculations started on registered fixed assets in Xero  # noqa: E501

        :param asset_start_date: The asset_start_date of this Setting.  # noqa: E501
        :type: date
        """

        self._asset_start_date = asset_start_date

    @property
    def last_depreciation_date(self):
        """Gets the last_depreciation_date of this Setting.  # noqa: E501

        The last depreciation date  # noqa: E501

        :return: The last_depreciation_date of this Setting.  # noqa: E501
        :rtype: date
        """
        return self._last_depreciation_date

    @last_depreciation_date.setter
    def last_depreciation_date(self, last_depreciation_date):
        """Sets the last_depreciation_date of this Setting.

        The last depreciation date  # noqa: E501

        :param last_depreciation_date: The last_depreciation_date of this Setting.  # noqa: E501
        :type: date
        """

        self._last_depreciation_date = last_depreciation_date

    @property
    def default_gain_on_disposal_account_id(self):
        """Gets the default_gain_on_disposal_account_id of this Setting.  # noqa: E501

        Default account that gains are posted to  # noqa: E501

        :return: The default_gain_on_disposal_account_id of this Setting.  # noqa: E501
        :rtype: str
        """
        return self._default_gain_on_disposal_account_id

    @default_gain_on_disposal_account_id.setter
    def default_gain_on_disposal_account_id(self, default_gain_on_disposal_account_id):
        """Sets the default_gain_on_disposal_account_id of this Setting.

        Default account that gains are posted to  # noqa: E501

        :param default_gain_on_disposal_account_id: The default_gain_on_disposal_account_id of this Setting.  # noqa: E501
        :type: str
        """

        self._default_gain_on_disposal_account_id = default_gain_on_disposal_account_id

    @property
    def default_loss_on_disposal_account_id(self):
        """Gets the default_loss_on_disposal_account_id of this Setting.  # noqa: E501

        Default account that losses are posted to  # noqa: E501

        :return: The default_loss_on_disposal_account_id of this Setting.  # noqa: E501
        :rtype: str
        """
        return self._default_loss_on_disposal_account_id

    @default_loss_on_disposal_account_id.setter
    def default_loss_on_disposal_account_id(self, default_loss_on_disposal_account_id):
        """Sets the default_loss_on_disposal_account_id of this Setting.

        Default account that losses are posted to  # noqa: E501

        :param default_loss_on_disposal_account_id: The default_loss_on_disposal_account_id of this Setting.  # noqa: E501
        :type: str
        """

        self._default_loss_on_disposal_account_id = default_loss_on_disposal_account_id

    @property
    def default_capital_gain_on_disposal_account_id(self):
        """Gets the default_capital_gain_on_disposal_account_id of this Setting.  # noqa: E501

        Default account that capital gains are posted to  # noqa: E501

        :return: The default_capital_gain_on_disposal_account_id of this Setting.  # noqa: E501
        :rtype: str
        """
        return self._default_capital_gain_on_disposal_account_id

    @default_capital_gain_on_disposal_account_id.setter
    def default_capital_gain_on_disposal_account_id(
        self, default_capital_gain_on_disposal_account_id
    ):
        """Sets the default_capital_gain_on_disposal_account_id of this Setting.

        Default account that capital gains are posted to  # noqa: E501

        :param default_capital_gain_on_disposal_account_id: The default_capital_gain_on_disposal_account_id of this Setting.  # noqa: E501
        :type: str
        """

        self._default_capital_gain_on_disposal_account_id = (
            default_capital_gain_on_disposal_account_id
        )

    @property
    def opt_in_for_tax(self):
        """Gets the opt_in_for_tax of this Setting.  # noqa: E501

        opt in for tax calculation  # noqa: E501

        :return: The opt_in_for_tax of this Setting.  # noqa: E501
        :rtype: bool
        """
        return self._opt_in_for_tax

    @opt_in_for_tax.setter
    def opt_in_for_tax(self, opt_in_for_tax):
        """Sets the opt_in_for_tax of this Setting.

        opt in for tax calculation  # noqa: E501

        :param opt_in_for_tax: The opt_in_for_tax of this Setting.  # noqa: E501
        :type: bool
        """

        self._opt_in_for_tax = opt_in_for_tax



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EmployeeStatutoryLeaveBalance(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"leave_type": "str", "balance_remaining": "float", "units": "str"}

    attribute_map = {
        "leave_type": "leaveType",
        "balance_remaining": "balanceRemaining",
        "units": "units",
    }

    def __init__(
        self, leave_type=None, balance_remaining=None, units=None
    ):  # noqa: E501
        """EmployeeStatutoryLeaveBalance - a model defined in OpenAPI"""  # noqa: E501

        self._leave_type = None
        self._balance_remaining = None
        self._units = None
        self.discriminator = None

        if leave_type is not None:
            self.leave_type = leave_type
        if balance_remaining is not None:
            self.balance_remaining = balance_remaining
        if units is not None:
            self.units = units

    @property
    def leave_type(self):
        """Gets the leave_type of this EmployeeStatutoryLeaveBalance.  # noqa: E501

        The type of statutory leave  # noqa: E501

        :return: The leave_type of this EmployeeStatutoryLeaveBalance.  # noqa: E501
        :rtype: str
        """
        return self._leave_type

    @leave_type.setter
    def leave_type(self, leave_type):
        """Sets the leave_type of this EmployeeStatutoryLeaveBalance.

        The type of statutory leave  # noqa: E501

        :param leave_type: The leave_type of this EmployeeStatutoryLeaveBalance.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "Sick",
            "Adoption",
            "Maternity",
            "Paternity",
            "Sharedparental",
            "None",
        ]  # noqa: E501

        if leave_type:
            if leave_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `leave_type` ({0}), must be one of {1}".format(  # noqa: E501
                        leave_type, allowed_values
                    )
                )

        self._leave_type = leave_type

    @property
    def balance_remaining(self):
        """Gets the balance_remaining of this EmployeeStatutoryLeaveBalance.  # noqa: E501

        The balance remaining for the corresponding leave type as of specified date.  # noqa: E501

        :return: The balance_remaining of this EmployeeStatutoryLeaveBalance.  # noqa: E501
        :rtype: float
        """
        return self._balance_remaining

    @balance_remaining.setter
    def balance_remaining(self, balance_remaining):
        """Sets the balance_remaining of this EmployeeStatutoryLeaveBalance.

        The balance remaining for the corresponding leave type as of specified date.  # noqa: E501

        :param balance_remaining: The balance_remaining of this EmployeeStatutoryLeaveBalance.  # noqa: E501
        :type: float
        """

        self._balance_remaining = balance_remaining

    @property
    def units(self):
        """Gets the units of this EmployeeStatutoryLeaveBalance.  # noqa: E501

        The units will be \"Hours\"  # noqa: E501

        :return: The units of this EmployeeStatutoryLeaveBalance.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this EmployeeStatutoryLeaveBalance.

        The units will be \"Hours\"  # noqa: E501

        :param units: The units of this EmployeeStatutoryLeaveBalance.  # noqa: E501
        :type: str
        """
        allowed_values = ["Hours", "None"]  # noqa: E501

        if units:
            if units not in allowed_values:
                raise ValueError(
                    "Invalid value for `units` ({0}), must be one of {1}".format(  # noqa: E501
                        units, allowed_values
                    )
                )

        self._units = units



# -*- coding: utf-8 -*-


class FakeMethod:
    def __init__(self, return_value=None):
        self.return_value = return_value
        self.calls = []

    def __call__(self, *args, **kwargs):
        self.calls.append((args, kwargs))
        return self.return_value


class FakeClass:
    pass



# -*- coding: utf-8 -*-
import pytest

from xero_python.api_client import ApiClient
from xero_python.identity import IdentityApi, models
from xero_python.rest import RESTClientObject


@pytest.fixture
def identity_api(api_client):
    return IdentityApi(api_client=api_client)


def test_identity_api_instance_configuration(identity_api):
    """
    Test IdentityApi() configured correctly
    """
    assert isinstance(identity_api, IdentityApi)
    assert isinstance(identity_api.api_client, ApiClient)
    assert isinstance(identity_api.api_client.rest_client, RESTClientObject)


@pytest.mark.vcr()
def test_get_connections(identity_api: IdentityApi):
    """
    Test IdentityApi.get_connections()
    """
    # Given correct api client and xero tenant id
    # When fetching connections
    response = identity_api.get_connections()
    # Then expect correct response with list of connections
    assert isinstance(response, list)
    assert len(response) == 1
    connection = response[0]
    assert isinstance(connection, models.Connection)
    assert connection.tenant_id



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class RepeatingInvoice(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "type": "str",
        "contact": "Contact",
        "schedule": "Schedule",
        "line_items": "list[LineItem]",
        "line_amount_types": "LineAmountTypes",
        "reference": "str",
        "branding_theme_id": "str",
        "currency_code": "CurrencyCode",
        "status": "str",
        "sub_total": "float",
        "total_tax": "float",
        "total": "float",
        "repeating_invoice_id": "str",
        "id": "str",
        "has_attachments": "bool",
        "attachments": "list[Attachment]",
    }

    attribute_map = {
        "type": "Type",
        "contact": "Contact",
        "schedule": "Schedule",
        "line_items": "LineItems",
        "line_amount_types": "LineAmountTypes",
        "reference": "Reference",
        "branding_theme_id": "BrandingThemeID",
        "currency_code": "CurrencyCode",
        "status": "Status",
        "sub_total": "SubTotal",
        "total_tax": "TotalTax",
        "total": "Total",
        "repeating_invoice_id": "RepeatingInvoiceID",
        "id": "ID",
        "has_attachments": "HasAttachments",
        "attachments": "Attachments",
    }

    def __init__(
        self,
        type=None,
        contact=None,
        schedule=None,
        line_items=None,
        line_amount_types=None,
        reference=None,
        branding_theme_id=None,
        currency_code=None,
        status=None,
        sub_total=None,
        total_tax=None,
        total=None,
        repeating_invoice_id=None,
        id=None,
        has_attachments=False,
        attachments=None,
    ):  # noqa: E501
        """RepeatingInvoice - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._contact = None
        self._schedule = None
        self._line_items = None
        self._line_amount_types = None
        self._reference = None
        self._branding_theme_id = None
        self._currency_code = None
        self._status = None
        self._sub_total = None
        self._total_tax = None
        self._total = None
        self._repeating_invoice_id = None
        self._id = None
        self._has_attachments = None
        self._attachments = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if contact is not None:
            self.contact = contact
        if schedule is not None:
            self.schedule = schedule
        if line_items is not None:
            self.line_items = line_items
        if line_amount_types is not None:
            self.line_amount_types = line_amount_types
        if reference is not None:
            self.reference = reference
        if branding_theme_id is not None:
            self.branding_theme_id = branding_theme_id
        if currency_code is not None:
            self.currency_code = currency_code
        if status is not None:
            self.status = status
        if sub_total is not None:
            self.sub_total = sub_total
        if total_tax is not None:
            self.total_tax = total_tax
        if total is not None:
            self.total = total
        if repeating_invoice_id is not None:
            self.repeating_invoice_id = repeating_invoice_id
        if id is not None:
            self.id = id
        if has_attachments is not None:
            self.has_attachments = has_attachments
        if attachments is not None:
            self.attachments = attachments

    @property
    def type(self):
        """Gets the type of this RepeatingInvoice.  # noqa: E501

        See Invoice Types  # noqa: E501

        :return: The type of this RepeatingInvoice.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RepeatingInvoice.

        See Invoice Types  # noqa: E501

        :param type: The type of this RepeatingInvoice.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACCPAY", "ACCREC", "None"]  # noqa: E501

        if type:
            if type not in allowed_values:
                raise ValueError(
                    "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                        type, allowed_values
                    )
                )

        self._type = type

    @property
    def contact(self):
        """Gets the contact of this RepeatingInvoice.  # noqa: E501


        :return: The contact of this RepeatingInvoice.  # noqa: E501
        :rtype: Contact
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this RepeatingInvoice.


        :param contact: The contact of this RepeatingInvoice.  # noqa: E501
        :type: Contact
        """

        self._contact = contact

    @property
    def schedule(self):
        """Gets the schedule of this RepeatingInvoice.  # noqa: E501


        :return: The schedule of this RepeatingInvoice.  # noqa: E501
        :rtype: Schedule
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this RepeatingInvoice.


        :param schedule: The schedule of this RepeatingInvoice.  # noqa: E501
        :type: Schedule
        """

        self._schedule = schedule

    @property
    def line_items(self):
        """Gets the line_items of this RepeatingInvoice.  # noqa: E501

        See LineItems  # noqa: E501

        :return: The line_items of this RepeatingInvoice.  # noqa: E501
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this RepeatingInvoice.

        See LineItems  # noqa: E501

        :param line_items: The line_items of this RepeatingInvoice.  # noqa: E501
        :type: list[LineItem]
        """

        self._line_items = line_items

    @property
    def line_amount_types(self):
        """Gets the line_amount_types of this RepeatingInvoice.  # noqa: E501


        :return: The line_amount_types of this RepeatingInvoice.  # noqa: E501
        :rtype: LineAmountTypes
        """
        return self._line_amount_types

    @line_amount_types.setter
    def line_amount_types(self, line_amount_types):
        """Sets the line_amount_types of this RepeatingInvoice.


        :param line_amount_types: The line_amount_types of this RepeatingInvoice.  # noqa: E501
        :type: LineAmountTypes
        """

        self._line_amount_types = line_amount_types

    @property
    def reference(self):
        """Gets the reference of this RepeatingInvoice.  # noqa: E501

        ACCREC only – additional reference number  # noqa: E501

        :return: The reference of this RepeatingInvoice.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this RepeatingInvoice.

        ACCREC only – additional reference number  # noqa: E501

        :param reference: The reference of this RepeatingInvoice.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def branding_theme_id(self):
        """Gets the branding_theme_id of this RepeatingInvoice.  # noqa: E501

        See BrandingThemes  # noqa: E501

        :return: The branding_theme_id of this RepeatingInvoice.  # noqa: E501
        :rtype: str
        """
        return self._branding_theme_id

    @branding_theme_id.setter
    def branding_theme_id(self, branding_theme_id):
        """Sets the branding_theme_id of this RepeatingInvoice.

        See BrandingThemes  # noqa: E501

        :param branding_theme_id: The branding_theme_id of this RepeatingInvoice.  # noqa: E501
        :type: str
        """

        self._branding_theme_id = branding_theme_id

    @property
    def currency_code(self):
        """Gets the currency_code of this RepeatingInvoice.  # noqa: E501


        :return: The currency_code of this RepeatingInvoice.  # noqa: E501
        :rtype: CurrencyCode
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this RepeatingInvoice.


        :param currency_code: The currency_code of this RepeatingInvoice.  # noqa: E501
        :type: CurrencyCode
        """

        self._currency_code = currency_code

    @property
    def status(self):
        """Gets the status of this RepeatingInvoice.  # noqa: E501

        One of the following - DRAFT or AUTHORISED – See Invoice Status Codes  # noqa: E501

        :return: The status of this RepeatingInvoice.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RepeatingInvoice.

        One of the following - DRAFT or AUTHORISED – See Invoice Status Codes  # noqa: E501

        :param status: The status of this RepeatingInvoice.  # noqa: E501
        :type: str
        """
        allowed_values = ["DRAFT", "AUTHORISED", "DELETED", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def sub_total(self):
        """Gets the sub_total of this RepeatingInvoice.  # noqa: E501

        Total of invoice excluding taxes  # noqa: E501

        :return: The sub_total of this RepeatingInvoice.  # noqa: E501
        :rtype: float
        """
        return self._sub_total

    @sub_total.setter
    def sub_total(self, sub_total):
        """Sets the sub_total of this RepeatingInvoice.

        Total of invoice excluding taxes  # noqa: E501

        :param sub_total: The sub_total of this RepeatingInvoice.  # noqa: E501
        :type: float
        """

        self._sub_total = sub_total

    @property
    def total_tax(self):
        """Gets the total_tax of this RepeatingInvoice.  # noqa: E501

        Total tax on invoice  # noqa: E501

        :return: The total_tax of this RepeatingInvoice.  # noqa: E501
        :rtype: float
        """
        return self._total_tax

    @total_tax.setter
    def total_tax(self, total_tax):
        """Sets the total_tax of this RepeatingInvoice.

        Total tax on invoice  # noqa: E501

        :param total_tax: The total_tax of this RepeatingInvoice.  # noqa: E501
        :type: float
        """

        self._total_tax = total_tax

    @property
    def total(self):
        """Gets the total of this RepeatingInvoice.  # noqa: E501

        Total of Invoice tax inclusive (i.e. SubTotal + TotalTax)  # noqa: E501

        :return: The total of this RepeatingInvoice.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this RepeatingInvoice.

        Total of Invoice tax inclusive (i.e. SubTotal + TotalTax)  # noqa: E501

        :param total: The total of this RepeatingInvoice.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def repeating_invoice_id(self):
        """Gets the repeating_invoice_id of this RepeatingInvoice.  # noqa: E501

        Xero generated unique identifier for repeating invoice template  # noqa: E501

        :return: The repeating_invoice_id of this RepeatingInvoice.  # noqa: E501
        :rtype: str
        """
        return self._repeating_invoice_id

    @repeating_invoice_id.setter
    def repeating_invoice_id(self, repeating_invoice_id):
        """Sets the repeating_invoice_id of this RepeatingInvoice.

        Xero generated unique identifier for repeating invoice template  # noqa: E501

        :param repeating_invoice_id: The repeating_invoice_id of this RepeatingInvoice.  # noqa: E501
        :type: str
        """

        self._repeating_invoice_id = repeating_invoice_id

    @property
    def id(self):
        """Gets the id of this RepeatingInvoice.  # noqa: E501

        Xero generated unique identifier for repeating invoice template  # noqa: E501

        :return: The id of this RepeatingInvoice.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RepeatingInvoice.

        Xero generated unique identifier for repeating invoice template  # noqa: E501

        :param id: The id of this RepeatingInvoice.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def has_attachments(self):
        """Gets the has_attachments of this RepeatingInvoice.  # noqa: E501

        boolean to indicate if an invoice has an attachment  # noqa: E501

        :return: The has_attachments of this RepeatingInvoice.  # noqa: E501
        :rtype: bool
        """
        return self._has_attachments

    @has_attachments.setter
    def has_attachments(self, has_attachments):
        """Sets the has_attachments of this RepeatingInvoice.

        boolean to indicate if an invoice has an attachment  # noqa: E501

        :param has_attachments: The has_attachments of this RepeatingInvoice.  # noqa: E501
        :type: bool
        """

        self._has_attachments = has_attachments

    @property
    def attachments(self):
        """Gets the attachments of this RepeatingInvoice.  # noqa: E501

        Displays array of attachments from the API  # noqa: E501

        :return: The attachments of this RepeatingInvoice.  # noqa: E501
        :rtype: list[Attachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this RepeatingInvoice.

        Displays array of attachments from the API  # noqa: E501

        :param attachments: The attachments of this RepeatingInvoice.  # noqa: E501
        :type: list[Attachment]
        """

        self._attachments = attachments



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Reimbursement(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "reimbursement_id": "str",
        "name": "str",
        "account_id": "str",
        "current_record": "bool",
        "reimbursement_category": "str",
        "calculation_type": "str",
        "standard_amount": "str",
        "standard_type_of_units": "str",
        "standard_rate_per_unit": "float",
    }

    attribute_map = {
        "reimbursement_id": "reimbursementID",
        "name": "name",
        "account_id": "accountID",
        "current_record": "currentRecord",
        "reimbursement_category": "reimbursementCategory",
        "calculation_type": "calculationType",
        "standard_amount": "standardAmount",
        "standard_type_of_units": "standardTypeOfUnits",
        "standard_rate_per_unit": "standardRatePerUnit",
    }

    def __init__(
        self,
        reimbursement_id=None,
        name=None,
        account_id=None,
        current_record=None,
        reimbursement_category=None,
        calculation_type=None,
        standard_amount=None,
        standard_type_of_units=None,
        standard_rate_per_unit=None,
    ):  # noqa: E501
        """Reimbursement - a model defined in OpenAPI"""  # noqa: E501

        self._reimbursement_id = None
        self._name = None
        self._account_id = None
        self._current_record = None
        self._reimbursement_category = None
        self._calculation_type = None
        self._standard_amount = None
        self._standard_type_of_units = None
        self._standard_rate_per_unit = None
        self.discriminator = None

        if reimbursement_id is not None:
            self.reimbursement_id = reimbursement_id
        self.name = name
        self.account_id = account_id
        if current_record is not None:
            self.current_record = current_record
        if reimbursement_category is not None:
            self.reimbursement_category = reimbursement_category
        if calculation_type is not None:
            self.calculation_type = calculation_type
        if standard_amount is not None:
            self.standard_amount = standard_amount
        if standard_type_of_units is not None:
            self.standard_type_of_units = standard_type_of_units
        if standard_rate_per_unit is not None:
            self.standard_rate_per_unit = standard_rate_per_unit

    @property
    def reimbursement_id(self):
        """Gets the reimbursement_id of this Reimbursement.  # noqa: E501

        Xero unique identifier for a reimbursement  # noqa: E501

        :return: The reimbursement_id of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._reimbursement_id

    @reimbursement_id.setter
    def reimbursement_id(self, reimbursement_id):
        """Sets the reimbursement_id of this Reimbursement.

        Xero unique identifier for a reimbursement  # noqa: E501

        :param reimbursement_id: The reimbursement_id of this Reimbursement.  # noqa: E501
        :type: str
        """

        self._reimbursement_id = reimbursement_id

    @property
    def name(self):
        """Gets the name of this Reimbursement.  # noqa: E501

        Name of the reimbursement  # noqa: E501

        :return: The name of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Reimbursement.

        Name of the reimbursement  # noqa: E501

        :param name: The name of this Reimbursement.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def account_id(self):
        """Gets the account_id of this Reimbursement.  # noqa: E501

        Xero unique identifier for the account used for the reimbursement  # noqa: E501

        :return: The account_id of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Reimbursement.

        Xero unique identifier for the account used for the reimbursement  # noqa: E501

        :param account_id: The account_id of this Reimbursement.  # noqa: E501
        :type: str
        """
        if account_id is None:
            raise ValueError(
                "Invalid value for `account_id`, must not be `None`"
            )  # noqa: E501

        self._account_id = account_id

    @property
    def current_record(self):
        """Gets the current_record of this Reimbursement.  # noqa: E501

        Indicates that whether the reimbursement is active  # noqa: E501

        :return: The current_record of this Reimbursement.  # noqa: E501
        :rtype: bool
        """
        return self._current_record

    @current_record.setter
    def current_record(self, current_record):
        """Sets the current_record of this Reimbursement.

        Indicates that whether the reimbursement is active  # noqa: E501

        :param current_record: The current_record of this Reimbursement.  # noqa: E501
        :type: bool
        """

        self._current_record = current_record

    @property
    def reimbursement_category(self):
        """Gets the reimbursement_category of this Reimbursement.  # noqa: E501

        See Reimbursement Categories  # noqa: E501

        :return: The reimbursement_category of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._reimbursement_category

    @reimbursement_category.setter
    def reimbursement_category(self, reimbursement_category):
        """Sets the reimbursement_category of this Reimbursement.

        See Reimbursement Categories  # noqa: E501

        :param reimbursement_category: The reimbursement_category of this Reimbursement.  # noqa: E501
        :type: str
        """
        allowed_values = ["GST", "NoGST", "GSTInclusive", "None"]  # noqa: E501

        if reimbursement_category:
            if reimbursement_category not in allowed_values:
                raise ValueError(
                    "Invalid value for `reimbursement_category` ({0}), must be one of {1}".format(  # noqa: E501
                        reimbursement_category, allowed_values
                    )
                )

        self._reimbursement_category = reimbursement_category

    @property
    def calculation_type(self):
        """Gets the calculation_type of this Reimbursement.  # noqa: E501

        See Calculation Types  # noqa: E501

        :return: The calculation_type of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._calculation_type

    @calculation_type.setter
    def calculation_type(self, calculation_type):
        """Sets the calculation_type of this Reimbursement.

        See Calculation Types  # noqa: E501

        :param calculation_type: The calculation_type of this Reimbursement.  # noqa: E501
        :type: str
        """
        allowed_values = ["Unknown", "FixedAmount", "RatePerUnit", "None"]  # noqa: E501

        if calculation_type:
            if calculation_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `calculation_type` ({0}), must be one of {1}".format(  # noqa: E501
                        calculation_type, allowed_values
                    )
                )

        self._calculation_type = calculation_type

    @property
    def standard_amount(self):
        """Gets the standard_amount of this Reimbursement.  # noqa: E501

        Optional Fixed Rate Amount. Applicable when calculation type is Fixed Amount  # noqa: E501

        :return: The standard_amount of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._standard_amount

    @standard_amount.setter
    def standard_amount(self, standard_amount):
        """Sets the standard_amount of this Reimbursement.

        Optional Fixed Rate Amount. Applicable when calculation type is Fixed Amount  # noqa: E501

        :param standard_amount: The standard_amount of this Reimbursement.  # noqa: E501
        :type: str
        """

        self._standard_amount = standard_amount

    @property
    def standard_type_of_units(self):
        """Gets the standard_type_of_units of this Reimbursement.  # noqa: E501

        Optional Type Of Units. Applicable when calculation type is Rate Per Unit  # noqa: E501

        :return: The standard_type_of_units of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._standard_type_of_units

    @standard_type_of_units.setter
    def standard_type_of_units(self, standard_type_of_units):
        """Sets the standard_type_of_units of this Reimbursement.

        Optional Type Of Units. Applicable when calculation type is Rate Per Unit  # noqa: E501

        :param standard_type_of_units: The standard_type_of_units of this Reimbursement.  # noqa: E501
        :type: str
        """
        allowed_values = ["Hours", "km", "None"]  # noqa: E501

        if standard_type_of_units:
            if standard_type_of_units not in allowed_values:
                raise ValueError(
                    "Invalid value for `standard_type_of_units` ({0}), must be one of {1}".format(  # noqa: E501
                        standard_type_of_units, allowed_values
                    )
                )

        self._standard_type_of_units = standard_type_of_units

    @property
    def standard_rate_per_unit(self):
        """Gets the standard_rate_per_unit of this Reimbursement.  # noqa: E501

        Optional Rate Per Unit. Applicable when calculation type is Rate Per Unit  # noqa: E501

        :return: The standard_rate_per_unit of this Reimbursement.  # noqa: E501
        :rtype: float
        """
        return self._standard_rate_per_unit

    @standard_rate_per_unit.setter
    def standard_rate_per_unit(self, standard_rate_per_unit):
        """Sets the standard_rate_per_unit of this Reimbursement.

        Optional Rate Per Unit. Applicable when calculation type is Rate Per Unit  # noqa: E501

        :param standard_rate_per_unit: The standard_rate_per_unit of this Reimbursement.  # noqa: E501
        :type: float
        """

        self._standard_rate_per_unit = standard_rate_per_unit



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Journal(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "journal_id": "str",
        "journal_date": "date[ms-format]",
        "journal_number": "int",
        "created_date_utc": "datetime[ms-format]",
        "reference": "str",
        "source_id": "str",
        "source_type": "str",
        "journal_lines": "list[JournalLine]",
    }

    attribute_map = {
        "journal_id": "JournalID",
        "journal_date": "JournalDate",
        "journal_number": "JournalNumber",
        "created_date_utc": "CreatedDateUTC",
        "reference": "Reference",
        "source_id": "SourceID",
        "source_type": "SourceType",
        "journal_lines": "JournalLines",
    }

    def __init__(
        self,
        journal_id=None,
        journal_date=None,
        journal_number=None,
        created_date_utc=None,
        reference=None,
        source_id=None,
        source_type=None,
        journal_lines=None,
    ):  # noqa: E501
        """Journal - a model defined in OpenAPI"""  # noqa: E501

        self._journal_id = None
        self._journal_date = None
        self._journal_number = None
        self._created_date_utc = None
        self._reference = None
        self._source_id = None
        self._source_type = None
        self._journal_lines = None
        self.discriminator = None

        if journal_id is not None:
            self.journal_id = journal_id
        if journal_date is not None:
            self.journal_date = journal_date
        if journal_number is not None:
            self.journal_number = journal_number
        if created_date_utc is not None:
            self.created_date_utc = created_date_utc
        if reference is not None:
            self.reference = reference
        if source_id is not None:
            self.source_id = source_id
        if source_type is not None:
            self.source_type = source_type
        if journal_lines is not None:
            self.journal_lines = journal_lines

    @property
    def journal_id(self):
        """Gets the journal_id of this Journal.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The journal_id of this Journal.  # noqa: E501
        :rtype: str
        """
        return self._journal_id

    @journal_id.setter
    def journal_id(self, journal_id):
        """Sets the journal_id of this Journal.

        Xero identifier  # noqa: E501

        :param journal_id: The journal_id of this Journal.  # noqa: E501
        :type: str
        """

        self._journal_id = journal_id

    @property
    def journal_date(self):
        """Gets the journal_date of this Journal.  # noqa: E501

        Date the journal was posted  # noqa: E501

        :return: The journal_date of this Journal.  # noqa: E501
        :rtype: date
        """
        return self._journal_date

    @journal_date.setter
    def journal_date(self, journal_date):
        """Sets the journal_date of this Journal.

        Date the journal was posted  # noqa: E501

        :param journal_date: The journal_date of this Journal.  # noqa: E501
        :type: date
        """

        self._journal_date = journal_date

    @property
    def journal_number(self):
        """Gets the journal_number of this Journal.  # noqa: E501

        Xero generated journal number  # noqa: E501

        :return: The journal_number of this Journal.  # noqa: E501
        :rtype: int
        """
        return self._journal_number

    @journal_number.setter
    def journal_number(self, journal_number):
        """Sets the journal_number of this Journal.

        Xero generated journal number  # noqa: E501

        :param journal_number: The journal_number of this Journal.  # noqa: E501
        :type: int
        """

        self._journal_number = journal_number

    @property
    def created_date_utc(self):
        """Gets the created_date_utc of this Journal.  # noqa: E501

        Created date UTC format  # noqa: E501

        :return: The created_date_utc of this Journal.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date_utc

    @created_date_utc.setter
    def created_date_utc(self, created_date_utc):
        """Sets the created_date_utc of this Journal.

        Created date UTC format  # noqa: E501

        :param created_date_utc: The created_date_utc of this Journal.  # noqa: E501
        :type: datetime
        """

        self._created_date_utc = created_date_utc

    @property
    def reference(self):
        """Gets the reference of this Journal.  # noqa: E501

        reference field for additional indetifying information  # noqa: E501

        :return: The reference of this Journal.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this Journal.

        reference field for additional indetifying information  # noqa: E501

        :param reference: The reference of this Journal.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def source_id(self):
        """Gets the source_id of this Journal.  # noqa: E501

        The identifier for the source transaction (e.g. InvoiceID)  # noqa: E501

        :return: The source_id of this Journal.  # noqa: E501
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """Sets the source_id of this Journal.

        The identifier for the source transaction (e.g. InvoiceID)  # noqa: E501

        :param source_id: The source_id of this Journal.  # noqa: E501
        :type: str
        """

        self._source_id = source_id

    @property
    def source_type(self):
        """Gets the source_type of this Journal.  # noqa: E501

        The journal source type. The type of transaction that created the journal  # noqa: E501

        :return: The source_type of this Journal.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this Journal.

        The journal source type. The type of transaction that created the journal  # noqa: E501

        :param source_type: The source_type of this Journal.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "ACCREC",
            "ACCPAY",
            "ACCRECCREDIT",
            "ACCPAYCREDIT",
            "ACCRECPAYMENT",
            "ACCPAYPAYMENT",
            "ARCREDITPAYMENT",
            "APCREDITPAYMENT",
            "CASHREC",
            "CASHPAID",
            "TRANSFER",
            "ARPREPAYMENT",
            "APPREPAYMENT",
            "AROVERPAYMENT",
            "APOVERPAYMENT",
            "EXPCLAIM",
            "EXPPAYMENT",
            "MANJOURNAL",
            "PAYSLIP",
            "WAGEPAYABLE",
            "INTEGRATEDPAYROLLPE",
            "INTEGRATEDPAYROLLPT",
            "EXTERNALSPENDMONEY",
            "INTEGRATEDPAYROLLPTPAYMENT",
            "INTEGRATEDPAYROLLCN",
            "None",
        ]  # noqa: E501

        if source_type:
            if source_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `source_type` ({0}), must be one of {1}".format(  # noqa: E501
                        source_type, allowed_values
                    )
                )

        self._source_type = source_type

    @property
    def journal_lines(self):
        """Gets the journal_lines of this Journal.  # noqa: E501

        See JournalLines  # noqa: E501

        :return: The journal_lines of this Journal.  # noqa: E501
        :rtype: list[JournalLine]
        """
        return self._journal_lines

    @journal_lines.setter
    def journal_lines(self, journal_lines):
        """Sets the journal_lines of this Journal.

        See JournalLines  # noqa: E501

        :param journal_lines: The journal_lines of this Journal.  # noqa: E501
        :type: list[JournalLine]
        """

        self._journal_lines = journal_lines



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ConversionBalances(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "account_code": "str",
        "balance": "float",
        "balance_details": "list[BalanceDetails]",
    }

    attribute_map = {
        "account_code": "AccountCode",
        "balance": "Balance",
        "balance_details": "BalanceDetails",
    }

    def __init__(
        self, account_code=None, balance=None, balance_details=None
    ):  # noqa: E501
        """ConversionBalances - a model defined in OpenAPI"""  # noqa: E501

        self._account_code = None
        self._balance = None
        self._balance_details = None
        self.discriminator = None

        if account_code is not None:
            self.account_code = account_code
        if balance is not None:
            self.balance = balance
        if balance_details is not None:
            self.balance_details = balance_details

    @property
    def account_code(self):
        """Gets the account_code of this ConversionBalances.  # noqa: E501

        The account code for a account  # noqa: E501

        :return: The account_code of this ConversionBalances.  # noqa: E501
        :rtype: str
        """
        return self._account_code

    @account_code.setter
    def account_code(self, account_code):
        """Sets the account_code of this ConversionBalances.

        The account code for a account  # noqa: E501

        :param account_code: The account_code of this ConversionBalances.  # noqa: E501
        :type: str
        """

        self._account_code = account_code

    @property
    def balance(self):
        """Gets the balance of this ConversionBalances.  # noqa: E501

        The opening balances of the account. Debits are positive, credits are negative values  # noqa: E501

        :return: The balance of this ConversionBalances.  # noqa: E501
        :rtype: float
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this ConversionBalances.

        The opening balances of the account. Debits are positive, credits are negative values  # noqa: E501

        :param balance: The balance of this ConversionBalances.  # noqa: E501
        :type: float
        """

        self._balance = balance

    @property
    def balance_details(self):
        """Gets the balance_details of this ConversionBalances.  # noqa: E501


        :return: The balance_details of this ConversionBalances.  # noqa: E501
        :rtype: list[BalanceDetails]
        """
        return self._balance_details

    @balance_details.setter
    def balance_details(self, balance_details):
        """Sets the balance_details of this ConversionBalances.


        :param balance_details: The balance_details of this ConversionBalances.  # noqa: E501
        :type: list[BalanceDetails]
        """

        self._balance_details = balance_details



# coding: utf-8

"""
    Xero OAuth 2 Identity Service API

    These endpoints are related to managing authentication tokens and identity for Xero API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class RefreshToken(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "grant_type": "str",
        "refresh_token": "str",
        "client_id": "str",
        "client_secret": "str",
    }

    attribute_map = {
        "grant_type": "grant_type",
        "refresh_token": "refresh_token",
        "client_id": "client_id",
        "client_secret": "client_secret",
    }

    def __init__(
        self, grant_type=None, refresh_token=None, client_id=None, client_secret=None
    ):  # noqa: E501
        """RefreshToken - a model defined in OpenAPI"""  # noqa: E501

        self._grant_type = None
        self._refresh_token = None
        self._client_id = None
        self._client_secret = None
        self.discriminator = None

        if grant_type is not None:
            self.grant_type = grant_type
        if refresh_token is not None:
            self.refresh_token = refresh_token
        if client_id is not None:
            self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret

    @property
    def grant_type(self):
        """Gets the grant_type of this RefreshToken.  # noqa: E501

        Xero grant type  # noqa: E501

        :return: The grant_type of this RefreshToken.  # noqa: E501
        :rtype: str
        """
        return self._grant_type

    @grant_type.setter
    def grant_type(self, grant_type):
        """Sets the grant_type of this RefreshToken.

        Xero grant type  # noqa: E501

        :param grant_type: The grant_type of this RefreshToken.  # noqa: E501
        :type: str
        """

        self._grant_type = grant_type

    @property
    def refresh_token(self):
        """Gets the refresh_token of this RefreshToken.  # noqa: E501

        refresh token provided during authentication flow  # noqa: E501

        :return: The refresh_token of this RefreshToken.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this RefreshToken.

        refresh token provided during authentication flow  # noqa: E501

        :param refresh_token: The refresh_token of this RefreshToken.  # noqa: E501
        :type: str
        """

        self._refresh_token = refresh_token

    @property
    def client_id(self):
        """Gets the client_id of this RefreshToken.  # noqa: E501

        client id for Xero app  # noqa: E501

        :return: The client_id of this RefreshToken.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this RefreshToken.

        client id for Xero app  # noqa: E501

        :param client_id: The client_id of this RefreshToken.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this RefreshToken.  # noqa: E501

        client secret for Xero app 2  # noqa: E501

        :return: The client_secret of this RefreshToken.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this RefreshToken.

        client secret for Xero app 2  # noqa: E501

        :param client_secret: The client_secret of this RefreshToken.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Account(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "code": "str",
        "name": "str",
        "account_id": "str",
        "type": "AccountType",
        "bank_account_number": "str",
        "status": "str",
        "description": "str",
        "bank_account_type": "str",
        "currency_code": "CurrencyCode",
        "tax_type": "str",
        "enable_payments_to_account": "bool",
        "show_in_expense_claims": "bool",
        "_class": "str",
        "system_account": "str",
        "reporting_code": "str",
        "reporting_code_name": "str",
        "has_attachments": "bool",
        "updated_date_utc": "datetime[ms-format]",
        "add_to_watchlist": "bool",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "code": "Code",
        "name": "Name",
        "account_id": "AccountID",
        "type": "Type",
        "bank_account_number": "BankAccountNumber",
        "status": "Status",
        "description": "Description",
        "bank_account_type": "BankAccountType",
        "currency_code": "CurrencyCode",
        "tax_type": "TaxType",
        "enable_payments_to_account": "EnablePaymentsToAccount",
        "show_in_expense_claims": "ShowInExpenseClaims",
        "_class": "Class",
        "system_account": "SystemAccount",
        "reporting_code": "ReportingCode",
        "reporting_code_name": "ReportingCodeName",
        "has_attachments": "HasAttachments",
        "updated_date_utc": "UpdatedDateUTC",
        "add_to_watchlist": "AddToWatchlist",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        code=None,
        name=None,
        account_id=None,
        type=None,
        bank_account_number=None,
        status=None,
        description=None,
        bank_account_type=None,
        currency_code=None,
        tax_type=None,
        enable_payments_to_account=None,
        show_in_expense_claims=None,
        _class=None,
        system_account=None,
        reporting_code=None,
        reporting_code_name=None,
        has_attachments=False,
        updated_date_utc=None,
        add_to_watchlist=None,
        validation_errors=None,
    ):  # noqa: E501
        """Account - a model defined in OpenAPI"""  # noqa: E501

        self._code = None
        self._name = None
        self._account_id = None
        self._type = None
        self._bank_account_number = None
        self._status = None
        self._description = None
        self._bank_account_type = None
        self._currency_code = None
        self._tax_type = None
        self._enable_payments_to_account = None
        self._show_in_expense_claims = None
        self.__class = None
        self._system_account = None
        self._reporting_code = None
        self._reporting_code_name = None
        self._has_attachments = None
        self._updated_date_utc = None
        self._add_to_watchlist = None
        self._validation_errors = None
        self.discriminator = None

        if code is not None:
            self.code = code
        if name is not None:
            self.name = name
        if account_id is not None:
            self.account_id = account_id
        if type is not None:
            self.type = type
        if bank_account_number is not None:
            self.bank_account_number = bank_account_number
        if status is not None:
            self.status = status
        if description is not None:
            self.description = description
        if bank_account_type is not None:
            self.bank_account_type = bank_account_type
        if currency_code is not None:
            self.currency_code = currency_code
        if tax_type is not None:
            self.tax_type = tax_type
        if enable_payments_to_account is not None:
            self.enable_payments_to_account = enable_payments_to_account
        if show_in_expense_claims is not None:
            self.show_in_expense_claims = show_in_expense_claims
        if _class is not None:
            self._class = _class
        if system_account is not None:
            self.system_account = system_account
        if reporting_code is not None:
            self.reporting_code = reporting_code
        if reporting_code_name is not None:
            self.reporting_code_name = reporting_code_name
        if has_attachments is not None:
            self.has_attachments = has_attachments
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if add_to_watchlist is not None:
            self.add_to_watchlist = add_to_watchlist
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def code(self):
        """Gets the code of this Account.  # noqa: E501

        Customer defined alpha numeric account code e.g 200 or SALES (max length = 10)  # noqa: E501

        :return: The code of this Account.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Account.

        Customer defined alpha numeric account code e.g 200 or SALES (max length = 10)  # noqa: E501

        :param code: The code of this Account.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def name(self):
        """Gets the name of this Account.  # noqa: E501

        Name of account (max length = 150)  # noqa: E501

        :return: The name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Account.

        Name of account (max length = 150)  # noqa: E501

        :param name: The name of this Account.  # noqa: E501
        :type: str
        """
        if name is not None and len(name) > 150:
            raise ValueError(
                "Invalid value for `name`, "
                "length must be less than or equal to `150`"
            )  # noqa: E501

        self._name = name

    @property
    def account_id(self):
        """Gets the account_id of this Account.  # noqa: E501

        The Xero identifier for an account – specified as a string following  the endpoint name   e.g. /297c2dc5-cc47-4afd-8ec8-74990b8761e9  # noqa: E501

        :return: The account_id of this Account.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Account.

        The Xero identifier for an account – specified as a string following  the endpoint name   e.g. /297c2dc5-cc47-4afd-8ec8-74990b8761e9  # noqa: E501

        :param account_id: The account_id of this Account.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def type(self):
        """Gets the type of this Account.  # noqa: E501


        :return: The type of this Account.  # noqa: E501
        :rtype: AccountType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Account.


        :param type: The type of this Account.  # noqa: E501
        :type: AccountType
        """

        self._type = type

    @property
    def bank_account_number(self):
        """Gets the bank_account_number of this Account.  # noqa: E501

        For bank accounts only (Account Type BANK)  # noqa: E501

        :return: The bank_account_number of this Account.  # noqa: E501
        :rtype: str
        """
        return self._bank_account_number

    @bank_account_number.setter
    def bank_account_number(self, bank_account_number):
        """Sets the bank_account_number of this Account.

        For bank accounts only (Account Type BANK)  # noqa: E501

        :param bank_account_number: The bank_account_number of this Account.  # noqa: E501
        :type: str
        """

        self._bank_account_number = bank_account_number

    @property
    def status(self):
        """Gets the status of this Account.  # noqa: E501

        Accounts with a status of ACTIVE can be updated to ARCHIVED. See Account Status Codes  # noqa: E501

        :return: The status of this Account.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Account.

        Accounts with a status of ACTIVE can be updated to ARCHIVED. See Account Status Codes  # noqa: E501

        :param status: The status of this Account.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "ARCHIVED", "DELETED", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def description(self):
        """Gets the description of this Account.  # noqa: E501

        Description of the Account. Valid for all types of accounts except bank accounts (max length = 4000)  # noqa: E501

        :return: The description of this Account.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Account.

        Description of the Account. Valid for all types of accounts except bank accounts (max length = 4000)  # noqa: E501

        :param description: The description of this Account.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def bank_account_type(self):
        """Gets the bank_account_type of this Account.  # noqa: E501

        For bank accounts only. See Bank Account types  # noqa: E501

        :return: The bank_account_type of this Account.  # noqa: E501
        :rtype: str
        """
        return self._bank_account_type

    @bank_account_type.setter
    def bank_account_type(self, bank_account_type):
        """Sets the bank_account_type of this Account.

        For bank accounts only. See Bank Account types  # noqa: E501

        :param bank_account_type: The bank_account_type of this Account.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "BANK",
            "CREDITCARD",
            "PAYPAL",
            "NONE",
            "",
            "None",
        ]  # noqa: E501

        if bank_account_type:
            if bank_account_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `bank_account_type` ({0}), must be one of {1}".format(  # noqa: E501
                        bank_account_type, allowed_values
                    )
                )

        self._bank_account_type = bank_account_type

    @property
    def currency_code(self):
        """Gets the currency_code of this Account.  # noqa: E501


        :return: The currency_code of this Account.  # noqa: E501
        :rtype: CurrencyCode
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this Account.


        :param currency_code: The currency_code of this Account.  # noqa: E501
        :type: CurrencyCode
        """

        self._currency_code = currency_code

    @property
    def tax_type(self):
        """Gets the tax_type of this Account.  # noqa: E501

        The tax type from TaxRates  # noqa: E501

        :return: The tax_type of this Account.  # noqa: E501
        :rtype: str
        """
        return self._tax_type

    @tax_type.setter
    def tax_type(self, tax_type):
        """Sets the tax_type of this Account.

        The tax type from TaxRates  # noqa: E501

        :param tax_type: The tax_type of this Account.  # noqa: E501
        :type: str
        """

        self._tax_type = tax_type

    @property
    def enable_payments_to_account(self):
        """Gets the enable_payments_to_account of this Account.  # noqa: E501

        Boolean – describes whether account can have payments applied to it  # noqa: E501

        :return: The enable_payments_to_account of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._enable_payments_to_account

    @enable_payments_to_account.setter
    def enable_payments_to_account(self, enable_payments_to_account):
        """Sets the enable_payments_to_account of this Account.

        Boolean – describes whether account can have payments applied to it  # noqa: E501

        :param enable_payments_to_account: The enable_payments_to_account of this Account.  # noqa: E501
        :type: bool
        """

        self._enable_payments_to_account = enable_payments_to_account

    @property
    def show_in_expense_claims(self):
        """Gets the show_in_expense_claims of this Account.  # noqa: E501

        Boolean – describes whether account code is available for use with expense claims  # noqa: E501

        :return: The show_in_expense_claims of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._show_in_expense_claims

    @show_in_expense_claims.setter
    def show_in_expense_claims(self, show_in_expense_claims):
        """Sets the show_in_expense_claims of this Account.

        Boolean – describes whether account code is available for use with expense claims  # noqa: E501

        :param show_in_expense_claims: The show_in_expense_claims of this Account.  # noqa: E501
        :type: bool
        """

        self._show_in_expense_claims = show_in_expense_claims

    @property
    def _class(self):
        """Gets the _class of this Account.  # noqa: E501

        See Account Class Types  # noqa: E501

        :return: The _class of this Account.  # noqa: E501
        :rtype: str
        """
        return self.__class

    @_class.setter
    def _class(self, _class):
        """Sets the _class of this Account.

        See Account Class Types  # noqa: E501

        :param _class: The _class of this Account.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "ASSET",
            "EQUITY",
            "EXPENSE",
            "LIABILITY",
            "REVENUE",
            "None",
        ]  # noqa: E501

        if _class:
            if _class not in allowed_values:
                raise ValueError(
                    "Invalid value for `_class` ({0}), must be one of {1}".format(  # noqa: E501
                        _class, allowed_values
                    )
                )

        self.__class = _class

    @property
    def system_account(self):
        """Gets the system_account of this Account.  # noqa: E501

        If this is a system account then this element is returned. See System Account types. Note that non-system accounts may have this element set as either “” or null.  # noqa: E501

        :return: The system_account of this Account.  # noqa: E501
        :rtype: str
        """
        return self._system_account

    @system_account.setter
    def system_account(self, system_account):
        """Sets the system_account of this Account.

        If this is a system account then this element is returned. See System Account types. Note that non-system accounts may have this element set as either “” or null.  # noqa: E501

        :param system_account: The system_account of this Account.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "DEBTORS",
            "CREDITORS",
            "BANKCURRENCYGAIN",
            "GST",
            "GSTONIMPORTS",
            "HISTORICAL",
            "REALISEDCURRENCYGAIN",
            "RETAINEDEARNINGS",
            "ROUNDING",
            "TRACKINGTRANSFERS",
            "UNPAIDEXPCLM",
            "UNREALISEDCURRENCYGAIN",
            "WAGEPAYABLES",
            "CISASSETS",
            "CISASSET",
            "CISLABOUR",
            "CISLABOUREXPENSE",
            "CISLABOURINCOME",
            "CISLIABILITY",
            "CISMATERIALS",
            "",
            "None",
        ]  # noqa: E501

        if system_account:
            if system_account not in allowed_values:
                raise ValueError(
                    "Invalid value for `system_account` ({0}), must be one of {1}".format(  # noqa: E501
                        system_account, allowed_values
                    )
                )

        self._system_account = system_account

    @property
    def reporting_code(self):
        """Gets the reporting_code of this Account.  # noqa: E501

        Shown if set  # noqa: E501

        :return: The reporting_code of this Account.  # noqa: E501
        :rtype: str
        """
        return self._reporting_code

    @reporting_code.setter
    def reporting_code(self, reporting_code):
        """Sets the reporting_code of this Account.

        Shown if set  # noqa: E501

        :param reporting_code: The reporting_code of this Account.  # noqa: E501
        :type: str
        """

        self._reporting_code = reporting_code

    @property
    def reporting_code_name(self):
        """Gets the reporting_code_name of this Account.  # noqa: E501

        Shown if set  # noqa: E501

        :return: The reporting_code_name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._reporting_code_name

    @reporting_code_name.setter
    def reporting_code_name(self, reporting_code_name):
        """Sets the reporting_code_name of this Account.

        Shown if set  # noqa: E501

        :param reporting_code_name: The reporting_code_name of this Account.  # noqa: E501
        :type: str
        """

        self._reporting_code_name = reporting_code_name

    @property
    def has_attachments(self):
        """Gets the has_attachments of this Account.  # noqa: E501

        boolean to indicate if an account has an attachment (read only)  # noqa: E501

        :return: The has_attachments of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._has_attachments

    @has_attachments.setter
    def has_attachments(self, has_attachments):
        """Sets the has_attachments of this Account.

        boolean to indicate if an account has an attachment (read only)  # noqa: E501

        :param has_attachments: The has_attachments of this Account.  # noqa: E501
        :type: bool
        """

        self._has_attachments = has_attachments

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Account.  # noqa: E501

        Last modified date UTC format  # noqa: E501

        :return: The updated_date_utc of this Account.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Account.

        Last modified date UTC format  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Account.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def add_to_watchlist(self):
        """Gets the add_to_watchlist of this Account.  # noqa: E501

        Boolean – describes whether the account is shown in the watchlist widget on the dashboard  # noqa: E501

        :return: The add_to_watchlist of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._add_to_watchlist

    @add_to_watchlist.setter
    def add_to_watchlist(self, add_to_watchlist):
        """Sets the add_to_watchlist of this Account.

        Boolean – describes whether the account is shown in the watchlist widget on the dashboard  # noqa: E501

        :param add_to_watchlist: The add_to_watchlist of this Account.  # noqa: E501
        :type: bool
        """

        self._add_to_watchlist = add_to_watchlist

    @property
    def validation_errors(self):
        """Gets the validation_errors of this Account.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this Account.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this Account.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this Account.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors
